# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import unittest


class InstantiationTest(unittest.TestCase):
    """ Chaincode related Test cases
    """

    # @unittest.expectedFailure
    def test_create_instantiation(self):
        # TODO impl
        # trans_act_pro_hand = None
        # instantiation = Instantiation()
        # self.assertTrue(instantiation, Instantiation)
        pass


if __name__ == '__main__':
    unittest.main()
