# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/token/expectations.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from hfc.protos.token import transaction_pb2 as hfc_dot_protos_dot_token_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/token/expectations.proto',
  package='token',
  syntax='proto3',
  serialized_options=_b('\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/token'),
  serialized_pb=_b('\n#hfc/protos/token/expectations.proto\x12\x05token\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"hfc/protos/token/transaction.proto\"W\n\x10TokenExpectation\x12\x34\n\x11plain_expectation\x18\x01 \x01(\x0b\x32\x17.token.PlainExpectationH\x00\x42\r\n\x0b\x45xpectation\"\x97\x01\n\x10PlainExpectation\x12:\n\x12import_expectation\x18\x01 \x01(\x0b\x32\x1c.token.PlainTokenExpectationH\x00\x12<\n\x14transfer_expectation\x18\x02 \x01(\x0b\x32\x1c.token.PlainTokenExpectationH\x00\x42\t\n\x07payload\"<\n\x15PlainTokenExpectation\x12#\n\x07outputs\x18\x01 \x03(\x0b\x32\x12.token.PlainOutputBQ\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/tokenb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_transaction__pb2.DESCRIPTOR,])




_TOKENEXPECTATION = _descriptor.Descriptor(
  name='TokenExpectation',
  full_name='token.TokenExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plain_expectation', full_name='token.TokenExpectation.plain_expectation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Expectation', full_name='token.TokenExpectation.Expectation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=115,
  serialized_end=202,
)


_PLAINEXPECTATION = _descriptor.Descriptor(
  name='PlainExpectation',
  full_name='token.PlainExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='import_expectation', full_name='token.PlainExpectation.import_expectation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_expectation', full_name='token.PlainExpectation.transfer_expectation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.PlainExpectation.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=205,
  serialized_end=356,
)


_PLAINTOKENEXPECTATION = _descriptor.Descriptor(
  name='PlainTokenExpectation',
  full_name='token.PlainTokenExpectation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='token.PlainTokenExpectation.outputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=418,
)

_TOKENEXPECTATION.fields_by_name['plain_expectation'].message_type = _PLAINEXPECTATION
_TOKENEXPECTATION.oneofs_by_name['Expectation'].fields.append(
  _TOKENEXPECTATION.fields_by_name['plain_expectation'])
_TOKENEXPECTATION.fields_by_name['plain_expectation'].containing_oneof = _TOKENEXPECTATION.oneofs_by_name['Expectation']
_PLAINEXPECTATION.fields_by_name['import_expectation'].message_type = _PLAINTOKENEXPECTATION
_PLAINEXPECTATION.fields_by_name['transfer_expectation'].message_type = _PLAINTOKENEXPECTATION
_PLAINEXPECTATION.oneofs_by_name['payload'].fields.append(
  _PLAINEXPECTATION.fields_by_name['import_expectation'])
_PLAINEXPECTATION.fields_by_name['import_expectation'].containing_oneof = _PLAINEXPECTATION.oneofs_by_name['payload']
_PLAINEXPECTATION.oneofs_by_name['payload'].fields.append(
  _PLAINEXPECTATION.fields_by_name['transfer_expectation'])
_PLAINEXPECTATION.fields_by_name['transfer_expectation'].containing_oneof = _PLAINEXPECTATION.oneofs_by_name['payload']
_PLAINTOKENEXPECTATION.fields_by_name['outputs'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._PLAINOUTPUT
DESCRIPTOR.message_types_by_name['TokenExpectation'] = _TOKENEXPECTATION
DESCRIPTOR.message_types_by_name['PlainExpectation'] = _PLAINEXPECTATION
DESCRIPTOR.message_types_by_name['PlainTokenExpectation'] = _PLAINTOKENEXPECTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenExpectation = _reflection.GeneratedProtocolMessageType('TokenExpectation', (_message.Message,), dict(
  DESCRIPTOR = _TOKENEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenExpectation)
  ))
_sym_db.RegisterMessage(TokenExpectation)

PlainExpectation = _reflection.GeneratedProtocolMessageType('PlainExpectation', (_message.Message,), dict(
  DESCRIPTOR = _PLAINEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainExpectation)
  ))
_sym_db.RegisterMessage(PlainExpectation)

PlainTokenExpectation = _reflection.GeneratedProtocolMessageType('PlainTokenExpectation', (_message.Message,), dict(
  DESCRIPTOR = _PLAINTOKENEXPECTATION,
  __module__ = 'hfc.protos.token.expectations_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainTokenExpectation)
  ))
_sym_db.RegisterMessage(PlainTokenExpectation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
