# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/idemix/idemix.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/idemix/idemix.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('Z$github.com/hyperledger/fabric/idemix'),
  serialized_pb=_b('\n\x1ehfc/protos/idemix/idemix.proto\"\x1b\n\x03\x45\x43P\x12\t\n\x01x\x18\x01 \x01(\x0c\x12\t\n\x01y\x18\x02 \x01(\x0c\"6\n\x04\x45\x43P2\x12\n\n\x02xa\x18\x01 \x01(\x0c\x12\n\n\x02xb\x18\x02 \x01(\x0c\x12\n\n\x02ya\x18\x03 \x01(\x0c\x12\n\n\x02yb\x18\x04 \x01(\x0c\"\xd9\x01\n\x0fIssuerPublicKey\x12\x17\n\x0f\x61ttribute_names\x18\x01 \x03(\t\x12\x12\n\x04h_sk\x18\x02 \x01(\x0b\x32\x04.ECP\x12\x14\n\x06h_rand\x18\x03 \x01(\x0b\x32\x04.ECP\x12\x15\n\x07h_attrs\x18\x04 \x03(\x0b\x32\x04.ECP\x12\x10\n\x01w\x18\x05 \x01(\x0b\x32\x05.ECP2\x12\x14\n\x06\x62\x61r_g1\x18\x06 \x01(\x0b\x32\x04.ECP\x12\x14\n\x06\x62\x61r_g2\x18\x07 \x01(\x0b\x32\x04.ECP\x12\x0f\n\x07proof_c\x18\x08 \x01(\x0c\x12\x0f\n\x07proof_s\x18\t \x01(\x0c\x12\x0c\n\x04hash\x18\n \x01(\x0c\"7\n\tIssuerKey\x12\x0b\n\x03isk\x18\x01 \x01(\x0c\x12\x1d\n\x03ipk\x18\x02 \x01(\x0b\x32\x10.IssuerPublicKey\"S\n\nCredential\x12\x0f\n\x01\x61\x18\x01 \x01(\x0b\x32\x04.ECP\x12\x0f\n\x01\x62\x18\x02 \x01(\x0b\x32\x04.ECP\x12\t\n\x01\x65\x18\x03 \x01(\x0c\x12\t\n\x01s\x18\x04 \x01(\x0c\x12\r\n\x05\x61ttrs\x18\x05 \x03(\x0c\"X\n\x0b\x43redRequest\x12\x11\n\x03nym\x18\x01 \x01(\x0b\x32\x04.ECP\x12\x14\n\x0cissuer_nonce\x18\x02 \x01(\x0c\x12\x0f\n\x07proof_c\x18\x03 \x01(\x0c\x12\x0f\n\x07proof_s\x18\x04 \x01(\x0c\"\x98\x03\n\tSignature\x12\x15\n\x07\x61_prime\x18\x01 \x01(\x0b\x32\x04.ECP\x12\x13\n\x05\x61_bar\x18\x02 \x01(\x0b\x32\x04.ECP\x12\x15\n\x07\x62_prime\x18\x03 \x01(\x0b\x32\x04.ECP\x12\x0f\n\x07proof_c\x18\x04 \x01(\x0c\x12\x12\n\nproof_s_sk\x18\x05 \x01(\x0c\x12\x11\n\tproof_s_e\x18\x06 \x01(\x0c\x12\x12\n\nproof_s_r2\x18\x07 \x01(\x0c\x12\x12\n\nproof_s_r3\x18\x08 \x01(\x0c\x12\x17\n\x0fproof_s_s_prime\x18\t \x01(\x0c\x12\x15\n\rproof_s_attrs\x18\n \x03(\x0c\x12\r\n\x05nonce\x18\x0b \x01(\x0c\x12\x11\n\x03nym\x18\x0c \x01(\x0b\x32\x04.ECP\x12\x15\n\rproof_s_r_nym\x18\r \x01(\x0c\x12\"\n\x13revocation_epoch_pk\x18\x0e \x01(\x0b\x32\x05.ECP2\x12\x19\n\x11revocation_pk_sig\x18\x0f \x01(\x0c\x12\r\n\x05\x65poch\x18\x10 \x01(\x03\x12\x31\n\x14non_revocation_proof\x18\x11 \x01(\x0b\x32\x13.NonRevocationProof\"J\n\x12NonRevocationProof\x12\x16\n\x0erevocation_alg\x18\x01 \x01(\x05\x12\x1c\n\x14non_revocation_proof\x18\x02 \x01(\x0c\"Y\n\x0cNymSignature\x12\x0f\n\x07proof_c\x18\x01 \x01(\x0c\x12\x12\n\nproof_s_sk\x18\x02 \x01(\x0c\x12\x15\n\rproof_s_r_nym\x18\x03 \x01(\x0c\x12\r\n\x05nonce\x18\x04 \x01(\x0c\"\x90\x01\n\x1f\x43redentialRevocationInformation\x12\r\n\x05\x65poch\x18\x01 \x01(\x03\x12\x17\n\x08\x65poch_pk\x18\x02 \x01(\x0b\x32\x05.ECP2\x12\x14\n\x0c\x65poch_pk_sig\x18\x03 \x01(\x0c\x12\x16\n\x0erevocation_alg\x18\x04 \x01(\x05\x12\x17\n\x0frevocation_data\x18\x05 \x01(\x0c\x42&Z$github.com/hyperledger/fabric/idemixb\x06proto3')
)




_ECP = _descriptor.Descriptor(
  name='ECP',
  full_name='ECP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ECP.x', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='ECP.y', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=61,
)


_ECP2 = _descriptor.Descriptor(
  name='ECP2',
  full_name='ECP2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xa', full_name='ECP2.xa', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xb', full_name='ECP2.xb', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ya', full_name='ECP2.ya', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yb', full_name='ECP2.yb', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=117,
)


_ISSUERPUBLICKEY = _descriptor.Descriptor(
  name='IssuerPublicKey',
  full_name='IssuerPublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_names', full_name='IssuerPublicKey.attribute_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_sk', full_name='IssuerPublicKey.h_sk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_rand', full_name='IssuerPublicKey.h_rand', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_attrs', full_name='IssuerPublicKey.h_attrs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='w', full_name='IssuerPublicKey.w', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_g1', full_name='IssuerPublicKey.bar_g1', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_g2', full_name='IssuerPublicKey.bar_g2', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_c', full_name='IssuerPublicKey.proof_c', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s', full_name='IssuerPublicKey.proof_s', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='IssuerPublicKey.hash', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=337,
)


_ISSUERKEY = _descriptor.Descriptor(
  name='IssuerKey',
  full_name='IssuerKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isk', full_name='IssuerKey.isk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipk', full_name='IssuerKey.ipk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=394,
)


_CREDENTIAL = _descriptor.Descriptor(
  name='Credential',
  full_name='Credential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='Credential.a', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b', full_name='Credential.b', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='e', full_name='Credential.e', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s', full_name='Credential.s', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attrs', full_name='Credential.attrs', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=479,
)


_CREDREQUEST = _descriptor.Descriptor(
  name='CredRequest',
  full_name='CredRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nym', full_name='CredRequest.nym', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issuer_nonce', full_name='CredRequest.issuer_nonce', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_c', full_name='CredRequest.proof_c', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s', full_name='CredRequest.proof_s', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=569,
)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a_prime', full_name='Signature.a_prime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a_bar', full_name='Signature.a_bar', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b_prime', full_name='Signature.b_prime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_c', full_name='Signature.proof_c', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_sk', full_name='Signature.proof_s_sk', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_e', full_name='Signature.proof_s_e', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_r2', full_name='Signature.proof_s_r2', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_r3', full_name='Signature.proof_s_r3', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_s_prime', full_name='Signature.proof_s_s_prime', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_attrs', full_name='Signature.proof_s_attrs', index=9,
      number=10, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='Signature.nonce', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nym', full_name='Signature.nym', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_r_nym', full_name='Signature.proof_s_r_nym', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_epoch_pk', full_name='Signature.revocation_epoch_pk', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_pk_sig', full_name='Signature.revocation_pk_sig', index=14,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='Signature.epoch', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_revocation_proof', full_name='Signature.non_revocation_proof', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=980,
)


_NONREVOCATIONPROOF = _descriptor.Descriptor(
  name='NonRevocationProof',
  full_name='NonRevocationProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='revocation_alg', full_name='NonRevocationProof.revocation_alg', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_revocation_proof', full_name='NonRevocationProof.non_revocation_proof', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1056,
)


_NYMSIGNATURE = _descriptor.Descriptor(
  name='NymSignature',
  full_name='NymSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proof_c', full_name='NymSignature.proof_c', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_sk', full_name='NymSignature.proof_s_sk', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_s_r_nym', full_name='NymSignature.proof_s_r_nym', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='NymSignature.nonce', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1147,
)


_CREDENTIALREVOCATIONINFORMATION = _descriptor.Descriptor(
  name='CredentialRevocationInformation',
  full_name='CredentialRevocationInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='epoch', full_name='CredentialRevocationInformation.epoch', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch_pk', full_name='CredentialRevocationInformation.epoch_pk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch_pk_sig', full_name='CredentialRevocationInformation.epoch_pk_sig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_alg', full_name='CredentialRevocationInformation.revocation_alg', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_data', full_name='CredentialRevocationInformation.revocation_data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1294,
)

_ISSUERPUBLICKEY.fields_by_name['h_sk'].message_type = _ECP
_ISSUERPUBLICKEY.fields_by_name['h_rand'].message_type = _ECP
_ISSUERPUBLICKEY.fields_by_name['h_attrs'].message_type = _ECP
_ISSUERPUBLICKEY.fields_by_name['w'].message_type = _ECP2
_ISSUERPUBLICKEY.fields_by_name['bar_g1'].message_type = _ECP
_ISSUERPUBLICKEY.fields_by_name['bar_g2'].message_type = _ECP
_ISSUERKEY.fields_by_name['ipk'].message_type = _ISSUERPUBLICKEY
_CREDENTIAL.fields_by_name['a'].message_type = _ECP
_CREDENTIAL.fields_by_name['b'].message_type = _ECP
_CREDREQUEST.fields_by_name['nym'].message_type = _ECP
_SIGNATURE.fields_by_name['a_prime'].message_type = _ECP
_SIGNATURE.fields_by_name['a_bar'].message_type = _ECP
_SIGNATURE.fields_by_name['b_prime'].message_type = _ECP
_SIGNATURE.fields_by_name['nym'].message_type = _ECP
_SIGNATURE.fields_by_name['revocation_epoch_pk'].message_type = _ECP2
_SIGNATURE.fields_by_name['non_revocation_proof'].message_type = _NONREVOCATIONPROOF
_CREDENTIALREVOCATIONINFORMATION.fields_by_name['epoch_pk'].message_type = _ECP2
DESCRIPTOR.message_types_by_name['ECP'] = _ECP
DESCRIPTOR.message_types_by_name['ECP2'] = _ECP2
DESCRIPTOR.message_types_by_name['IssuerPublicKey'] = _ISSUERPUBLICKEY
DESCRIPTOR.message_types_by_name['IssuerKey'] = _ISSUERKEY
DESCRIPTOR.message_types_by_name['Credential'] = _CREDENTIAL
DESCRIPTOR.message_types_by_name['CredRequest'] = _CREDREQUEST
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['NonRevocationProof'] = _NONREVOCATIONPROOF
DESCRIPTOR.message_types_by_name['NymSignature'] = _NYMSIGNATURE
DESCRIPTOR.message_types_by_name['CredentialRevocationInformation'] = _CREDENTIALREVOCATIONINFORMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ECP = _reflection.GeneratedProtocolMessageType('ECP', (_message.Message,), dict(
  DESCRIPTOR = _ECP,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:ECP)
  ))
_sym_db.RegisterMessage(ECP)

ECP2 = _reflection.GeneratedProtocolMessageType('ECP2', (_message.Message,), dict(
  DESCRIPTOR = _ECP2,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:ECP2)
  ))
_sym_db.RegisterMessage(ECP2)

IssuerPublicKey = _reflection.GeneratedProtocolMessageType('IssuerPublicKey', (_message.Message,), dict(
  DESCRIPTOR = _ISSUERPUBLICKEY,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:IssuerPublicKey)
  ))
_sym_db.RegisterMessage(IssuerPublicKey)

IssuerKey = _reflection.GeneratedProtocolMessageType('IssuerKey', (_message.Message,), dict(
  DESCRIPTOR = _ISSUERKEY,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:IssuerKey)
  ))
_sym_db.RegisterMessage(IssuerKey)

Credential = _reflection.GeneratedProtocolMessageType('Credential', (_message.Message,), dict(
  DESCRIPTOR = _CREDENTIAL,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:Credential)
  ))
_sym_db.RegisterMessage(Credential)

CredRequest = _reflection.GeneratedProtocolMessageType('CredRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREDREQUEST,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:CredRequest)
  ))
_sym_db.RegisterMessage(CredRequest)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), dict(
  DESCRIPTOR = _SIGNATURE,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:Signature)
  ))
_sym_db.RegisterMessage(Signature)

NonRevocationProof = _reflection.GeneratedProtocolMessageType('NonRevocationProof', (_message.Message,), dict(
  DESCRIPTOR = _NONREVOCATIONPROOF,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:NonRevocationProof)
  ))
_sym_db.RegisterMessage(NonRevocationProof)

NymSignature = _reflection.GeneratedProtocolMessageType('NymSignature', (_message.Message,), dict(
  DESCRIPTOR = _NYMSIGNATURE,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:NymSignature)
  ))
_sym_db.RegisterMessage(NymSignature)

CredentialRevocationInformation = _reflection.GeneratedProtocolMessageType('CredentialRevocationInformation', (_message.Message,), dict(
  DESCRIPTOR = _CREDENTIALREVOCATIONINFORMATION,
  __module__ = 'hfc.protos.idemix.idemix_pb2'
  # @@protoc_insertion_point(class_scope:CredentialRevocationInformation)
  ))
_sym_db.RegisterMessage(CredentialRevocationInformation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
