# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/peer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.peer import proposal_pb2 as hfc_dot_protos_dot_peer_dot_proposal__pb2
from hfc.protos.peer import proposal_response_pb2 as hfc_dot_protos_dot_peer_dot_proposal__response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/peer.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n\x1ahfc/protos/peer/peer.proto\x12\x06protos\x1a\x1ehfc/protos/peer/proposal.proto\x1a\'hfc/protos/peer/proposal_response.proto\"\x16\n\x06PeerID\x12\x0c\n\x04name\x18\x01 \x01(\t\";\n\x0cPeerEndpoint\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.protos.PeerID\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t2Q\n\x08\x45ndorser\x12\x45\n\x0fProcessProposal\x12\x16.protos.SignedProposal\x1a\x18.protos.ProposalResponse\"\x00\x42O\n\"org.hyperledger.fabric.protos.peerZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_peer_dot_proposal__pb2.DESCRIPTOR,hfc_dot_protos_dot_peer_dot_proposal__response__pb2.DESCRIPTOR,])




_PEERID = _descriptor.Descriptor(
  name='PeerID',
  full_name='protos.PeerID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.PeerID.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=133,
)


_PEERENDPOINT = _descriptor.Descriptor(
  name='PeerEndpoint',
  full_name='protos.PeerEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protos.PeerEndpoint.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='protos.PeerEndpoint.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=194,
)

_PEERENDPOINT.fields_by_name['id'].message_type = _PEERID
DESCRIPTOR.message_types_by_name['PeerID'] = _PEERID
DESCRIPTOR.message_types_by_name['PeerEndpoint'] = _PEERENDPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PeerID = _reflection.GeneratedProtocolMessageType('PeerID', (_message.Message,), dict(
  DESCRIPTOR = _PEERID,
  __module__ = 'hfc.protos.peer.peer_pb2'
  # @@protoc_insertion_point(class_scope:protos.PeerID)
  ))
_sym_db.RegisterMessage(PeerID)

PeerEndpoint = _reflection.GeneratedProtocolMessageType('PeerEndpoint', (_message.Message,), dict(
  DESCRIPTOR = _PEERENDPOINT,
  __module__ = 'hfc.protos.peer.peer_pb2'
  # @@protoc_insertion_point(class_scope:protos.PeerEndpoint)
  ))
_sym_db.RegisterMessage(PeerEndpoint)


DESCRIPTOR._options = None

_ENDORSER = _descriptor.ServiceDescriptor(
  name='Endorser',
  full_name='protos.Endorser',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=196,
  serialized_end=277,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessProposal',
    full_name='protos.Endorser.ProcessProposal',
    index=0,
    containing_service=None,
    input_type=hfc_dot_protos_dot_peer_dot_proposal__pb2._SIGNEDPROPOSAL,
    output_type=hfc_dot_protos_dot_peer_dot_proposal__response__pb2._PROPOSALRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENDORSER)

DESCRIPTOR.services_by_name['Endorser'] = _ENDORSER

# @@protoc_insertion_point(module_scope)
