# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/token/transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/token/transaction.proto',
  package='token',
  syntax='proto3',
  serialized_options=_b('Z*github.com/hyperledger/fabric/protos/token'),
  serialized_pb=_b('\n\"hfc/protos/token/transaction.proto\x12\x05token\"M\n\x10TokenTransaction\x12/\n\x0cplain_action\x18\x01 \x01(\x0b\x32\x17.token.PlainTokenActionH\x00\x42\x08\n\x06\x61\x63tion\"\x8b\x02\n\x10PlainTokenAction\x12*\n\x0cplain_import\x18\x01 \x01(\x0b\x32\x12.token.PlainImportH\x00\x12.\n\x0eplain_transfer\x18\x02 \x01(\x0b\x32\x14.token.PlainTransferH\x00\x12,\n\x0cplain_redeem\x18\x03 \x01(\x0b\x32\x14.token.PlainTransferH\x00\x12,\n\rplain_approve\x18\x04 \x01(\x0b\x32\x13.token.PlainApproveH\x00\x12\x37\n\x13plain_transfer_From\x18\x05 \x01(\x0b\x32\x18.token.PlainTransferFromH\x00\x42\x06\n\x04\x64\x61ta\"2\n\x0bPlainImport\x12#\n\x07outputs\x18\x01 \x03(\x0b\x32\x12.token.PlainOutput\"T\n\rPlainTransfer\x12\x1e\n\x06inputs\x18\x01 \x03(\x0b\x32\x0e.token.InputId\x12#\n\x07outputs\x18\x02 \x03(\x0b\x32\x12.token.PlainOutput\"\x8a\x01\n\x0cPlainApprove\x12\x1e\n\x06inputs\x18\x01 \x03(\x0b\x32\x0e.token.InputId\x12\x36\n\x11\x64\x65legated_outputs\x18\x02 \x03(\x0b\x32\x1b.token.PlainDelegatedOutput\x12\"\n\x06output\x18\x03 \x01(\x0b\x32\x12.token.PlainOutput\"\x8f\x01\n\x11PlainTransferFrom\x12\x1e\n\x06inputs\x18\x01 \x03(\x0b\x32\x0e.token.InputId\x12#\n\x07outputs\x18\x02 \x03(\x0b\x32\x12.token.PlainOutput\x12\x35\n\x10\x64\x65legated_output\x18\x03 \x01(\x0b\x32\x1b.token.PlainDelegatedOutput\"<\n\x0bPlainOutput\x12\r\n\x05owner\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x04\"\'\n\x07InputId\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\"Y\n\x14PlainDelegatedOutput\x12\r\n\x05owner\x18\x01 \x01(\x0c\x12\x12\n\ndelegatees\x18\x02 \x03(\x0c\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x10\n\x08quantity\x18\x04 \x01(\x04\x42,Z*github.com/hyperledger/fabric/protos/tokenb\x06proto3')
)




_TOKENTRANSACTION = _descriptor.Descriptor(
  name='TokenTransaction',
  full_name='token.TokenTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plain_action', full_name='token.TokenTransaction.plain_action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='token.TokenTransaction.action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=45,
  serialized_end=122,
)


_PLAINTOKENACTION = _descriptor.Descriptor(
  name='PlainTokenAction',
  full_name='token.PlainTokenAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plain_import', full_name='token.PlainTokenAction.plain_import', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plain_transfer', full_name='token.PlainTokenAction.plain_transfer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plain_redeem', full_name='token.PlainTokenAction.plain_redeem', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plain_approve', full_name='token.PlainTokenAction.plain_approve', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plain_transfer_From', full_name='token.PlainTokenAction.plain_transfer_From', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='token.PlainTokenAction.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=125,
  serialized_end=392,
)


_PLAINIMPORT = _descriptor.Descriptor(
  name='PlainImport',
  full_name='token.PlainImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='token.PlainImport.outputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=444,
)


_PLAINTRANSFER = _descriptor.Descriptor(
  name='PlainTransfer',
  full_name='token.PlainTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='token.PlainTransfer.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='token.PlainTransfer.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=530,
)


_PLAINAPPROVE = _descriptor.Descriptor(
  name='PlainApprove',
  full_name='token.PlainApprove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='token.PlainApprove.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delegated_outputs', full_name='token.PlainApprove.delegated_outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='token.PlainApprove.output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=671,
)


_PLAINTRANSFERFROM = _descriptor.Descriptor(
  name='PlainTransferFrom',
  full_name='token.PlainTransferFrom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='token.PlainTransferFrom.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='token.PlainTransferFrom.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delegated_output', full_name='token.PlainTransferFrom.delegated_output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=817,
)


_PLAINOUTPUT = _descriptor.Descriptor(
  name='PlainOutput',
  full_name='token.PlainOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='token.PlainOutput.owner', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.PlainOutput.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.PlainOutput.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=879,
)


_INPUTID = _descriptor.Descriptor(
  name='InputId',
  full_name='token.InputId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='token.InputId.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='token.InputId.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=920,
)


_PLAINDELEGATEDOUTPUT = _descriptor.Descriptor(
  name='PlainDelegatedOutput',
  full_name='token.PlainDelegatedOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='token.PlainDelegatedOutput.owner', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delegatees', full_name='token.PlainDelegatedOutput.delegatees', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.PlainDelegatedOutput.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.PlainDelegatedOutput.quantity', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1011,
)

_TOKENTRANSACTION.fields_by_name['plain_action'].message_type = _PLAINTOKENACTION
_TOKENTRANSACTION.oneofs_by_name['action'].fields.append(
  _TOKENTRANSACTION.fields_by_name['plain_action'])
_TOKENTRANSACTION.fields_by_name['plain_action'].containing_oneof = _TOKENTRANSACTION.oneofs_by_name['action']
_PLAINTOKENACTION.fields_by_name['plain_import'].message_type = _PLAINIMPORT
_PLAINTOKENACTION.fields_by_name['plain_transfer'].message_type = _PLAINTRANSFER
_PLAINTOKENACTION.fields_by_name['plain_redeem'].message_type = _PLAINTRANSFER
_PLAINTOKENACTION.fields_by_name['plain_approve'].message_type = _PLAINAPPROVE
_PLAINTOKENACTION.fields_by_name['plain_transfer_From'].message_type = _PLAINTRANSFERFROM
_PLAINTOKENACTION.oneofs_by_name['data'].fields.append(
  _PLAINTOKENACTION.fields_by_name['plain_import'])
_PLAINTOKENACTION.fields_by_name['plain_import'].containing_oneof = _PLAINTOKENACTION.oneofs_by_name['data']
_PLAINTOKENACTION.oneofs_by_name['data'].fields.append(
  _PLAINTOKENACTION.fields_by_name['plain_transfer'])
_PLAINTOKENACTION.fields_by_name['plain_transfer'].containing_oneof = _PLAINTOKENACTION.oneofs_by_name['data']
_PLAINTOKENACTION.oneofs_by_name['data'].fields.append(
  _PLAINTOKENACTION.fields_by_name['plain_redeem'])
_PLAINTOKENACTION.fields_by_name['plain_redeem'].containing_oneof = _PLAINTOKENACTION.oneofs_by_name['data']
_PLAINTOKENACTION.oneofs_by_name['data'].fields.append(
  _PLAINTOKENACTION.fields_by_name['plain_approve'])
_PLAINTOKENACTION.fields_by_name['plain_approve'].containing_oneof = _PLAINTOKENACTION.oneofs_by_name['data']
_PLAINTOKENACTION.oneofs_by_name['data'].fields.append(
  _PLAINTOKENACTION.fields_by_name['plain_transfer_From'])
_PLAINTOKENACTION.fields_by_name['plain_transfer_From'].containing_oneof = _PLAINTOKENACTION.oneofs_by_name['data']
_PLAINIMPORT.fields_by_name['outputs'].message_type = _PLAINOUTPUT
_PLAINTRANSFER.fields_by_name['inputs'].message_type = _INPUTID
_PLAINTRANSFER.fields_by_name['outputs'].message_type = _PLAINOUTPUT
_PLAINAPPROVE.fields_by_name['inputs'].message_type = _INPUTID
_PLAINAPPROVE.fields_by_name['delegated_outputs'].message_type = _PLAINDELEGATEDOUTPUT
_PLAINAPPROVE.fields_by_name['output'].message_type = _PLAINOUTPUT
_PLAINTRANSFERFROM.fields_by_name['inputs'].message_type = _INPUTID
_PLAINTRANSFERFROM.fields_by_name['outputs'].message_type = _PLAINOUTPUT
_PLAINTRANSFERFROM.fields_by_name['delegated_output'].message_type = _PLAINDELEGATEDOUTPUT
DESCRIPTOR.message_types_by_name['TokenTransaction'] = _TOKENTRANSACTION
DESCRIPTOR.message_types_by_name['PlainTokenAction'] = _PLAINTOKENACTION
DESCRIPTOR.message_types_by_name['PlainImport'] = _PLAINIMPORT
DESCRIPTOR.message_types_by_name['PlainTransfer'] = _PLAINTRANSFER
DESCRIPTOR.message_types_by_name['PlainApprove'] = _PLAINAPPROVE
DESCRIPTOR.message_types_by_name['PlainTransferFrom'] = _PLAINTRANSFERFROM
DESCRIPTOR.message_types_by_name['PlainOutput'] = _PLAINOUTPUT
DESCRIPTOR.message_types_by_name['InputId'] = _INPUTID
DESCRIPTOR.message_types_by_name['PlainDelegatedOutput'] = _PLAINDELEGATEDOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenTransaction = _reflection.GeneratedProtocolMessageType('TokenTransaction', (_message.Message,), dict(
  DESCRIPTOR = _TOKENTRANSACTION,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenTransaction)
  ))
_sym_db.RegisterMessage(TokenTransaction)

PlainTokenAction = _reflection.GeneratedProtocolMessageType('PlainTokenAction', (_message.Message,), dict(
  DESCRIPTOR = _PLAINTOKENACTION,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainTokenAction)
  ))
_sym_db.RegisterMessage(PlainTokenAction)

PlainImport = _reflection.GeneratedProtocolMessageType('PlainImport', (_message.Message,), dict(
  DESCRIPTOR = _PLAINIMPORT,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainImport)
  ))
_sym_db.RegisterMessage(PlainImport)

PlainTransfer = _reflection.GeneratedProtocolMessageType('PlainTransfer', (_message.Message,), dict(
  DESCRIPTOR = _PLAINTRANSFER,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainTransfer)
  ))
_sym_db.RegisterMessage(PlainTransfer)

PlainApprove = _reflection.GeneratedProtocolMessageType('PlainApprove', (_message.Message,), dict(
  DESCRIPTOR = _PLAINAPPROVE,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainApprove)
  ))
_sym_db.RegisterMessage(PlainApprove)

PlainTransferFrom = _reflection.GeneratedProtocolMessageType('PlainTransferFrom', (_message.Message,), dict(
  DESCRIPTOR = _PLAINTRANSFERFROM,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainTransferFrom)
  ))
_sym_db.RegisterMessage(PlainTransferFrom)

PlainOutput = _reflection.GeneratedProtocolMessageType('PlainOutput', (_message.Message,), dict(
  DESCRIPTOR = _PLAINOUTPUT,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainOutput)
  ))
_sym_db.RegisterMessage(PlainOutput)

InputId = _reflection.GeneratedProtocolMessageType('InputId', (_message.Message,), dict(
  DESCRIPTOR = _INPUTID,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.InputId)
  ))
_sym_db.RegisterMessage(InputId)

PlainDelegatedOutput = _reflection.GeneratedProtocolMessageType('PlainDelegatedOutput', (_message.Message,), dict(
  DESCRIPTOR = _PLAINDELEGATEDOUTPUT,
  __module__ = 'hfc.protos.token.transaction_pb2'
  # @@protoc_insertion_point(class_scope:token.PlainDelegatedOutput)
  ))
_sym_db.RegisterMessage(PlainDelegatedOutput)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
