# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/transientstore/transientstore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.ledger.rwset import rwset_pb2 as hfc_dot_protos_dot_ledger_dot_rwset_dot_rwset__pb2
from hfc.protos.common import collection_pb2 as hfc_dot_protos_dot_common_dot_collection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/transientstore/transientstore.proto',
  package='transientstore',
  syntax='proto3',
  serialized_options=_b('\n,org.hyperledger.fabric.protos.transientstoreZ3github.com/hyperledger/fabric/protos/transientstore'),
  serialized_pb=_b('\n.hfc/protos/transientstore/transientstore.proto\x12\x0etransientstore\x1a#hfc/protos/ledger/rwset/rwset.proto\x1a\"hfc/protos/common/collection.proto\"\xa2\x02\n\x1fTxPvtReadWriteSetWithConfigInfo\x12\x13\n\x0b\x65ndorsed_at\x18\x01 \x01(\x04\x12+\n\tpvt_rwset\x18\x02 \x01(\x0b\x32\x18.rwset.TxPvtReadWriteSet\x12\x62\n\x12\x63ollection_configs\x18\x03 \x03(\x0b\x32\x46.transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry\x1aY\n\x16\x43ollectionConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.common.CollectionConfigPackage:\x02\x38\x01\x42\x63\n,org.hyperledger.fabric.protos.transientstoreZ3github.com/hyperledger/fabric/protos/transientstoreb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_ledger_dot_rwset_dot_rwset__pb2.DESCRIPTOR,hfc_dot_protos_dot_common_dot_collection__pb2.DESCRIPTOR,])




_TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY = _descriptor.Descriptor(
  name='CollectionConfigsEntry',
  full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=430,
)

_TXPVTREADWRITESETWITHCONFIGINFO = _descriptor.Descriptor(
  name='TxPvtReadWriteSetWithConfigInfo',
  full_name='transientstore.TxPvtReadWriteSetWithConfigInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endorsed_at', full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.endorsed_at', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pvt_rwset', full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.pvt_rwset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_configs', full_name='transientstore.TxPvtReadWriteSetWithConfigInfo.collection_configs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=430,
)

_TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY.fields_by_name['value'].message_type = hfc_dot_protos_dot_common_dot_collection__pb2._COLLECTIONCONFIGPACKAGE
_TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY.containing_type = _TXPVTREADWRITESETWITHCONFIGINFO
_TXPVTREADWRITESETWITHCONFIGINFO.fields_by_name['pvt_rwset'].message_type = hfc_dot_protos_dot_ledger_dot_rwset_dot_rwset__pb2._TXPVTREADWRITESET
_TXPVTREADWRITESETWITHCONFIGINFO.fields_by_name['collection_configs'].message_type = _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY
DESCRIPTOR.message_types_by_name['TxPvtReadWriteSetWithConfigInfo'] = _TXPVTREADWRITESETWITHCONFIGINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TxPvtReadWriteSetWithConfigInfo = _reflection.GeneratedProtocolMessageType('TxPvtReadWriteSetWithConfigInfo', (_message.Message,), dict(

  CollectionConfigsEntry = _reflection.GeneratedProtocolMessageType('CollectionConfigsEntry', (_message.Message,), dict(
    DESCRIPTOR = _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY,
    __module__ = 'hfc.protos.transientstore.transientstore_pb2'
    # @@protoc_insertion_point(class_scope:transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry)
    ))
  ,
  DESCRIPTOR = _TXPVTREADWRITESETWITHCONFIGINFO,
  __module__ = 'hfc.protos.transientstore.transientstore_pb2'
  # @@protoc_insertion_point(class_scope:transientstore.TxPvtReadWriteSetWithConfigInfo)
  ))
_sym_db.RegisterMessage(TxPvtReadWriteSetWithConfigInfo)
_sym_db.RegisterMessage(TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry)


DESCRIPTOR._options = None
_TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._options = None
# @@protoc_insertion_point(module_scope)
