# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/discovery/protocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.gossip import message_pb2 as hfc_dot_protos_dot_gossip_dot_message__pb2
from hfc.protos.msp import msp_config_pb2 as hfc_dot_protos_dot_msp_dot_msp__config__pb2
from hfc.protos.msp import identities_pb2 as hfc_dot_protos_dot_msp_dot_identities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/discovery/protocol.proto',
  package='discovery',
  syntax='proto3',
  serialized_options=_b('Z.github.com/hyperledger/fabric/protos/discovery'),
  serialized_pb=_b('\n#hfc/protos/discovery/protocol.proto\x12\tdiscovery\x1a\x1fhfc/protos/gossip/message.proto\x1a\x1fhfc/protos/msp/msp_config.proto\x1a\x1fhfc/protos/msp/identities.proto\"3\n\rSignedRequest\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"Y\n\x07Request\x12+\n\x0e\x61uthentication\x18\x01 \x01(\x0b\x32\x13.discovery.AuthInfo\x12!\n\x07queries\x18\x02 \x03(\x0b\x32\x10.discovery.Query\"3\n\x08Response\x12\'\n\x07results\x18\x01 \x03(\x0b\x32\x16.discovery.QueryResult\"A\n\x08\x41uthInfo\x12\x17\n\x0f\x63lient_identity\x18\x01 \x01(\x0c\x12\x1c\n\x14\x63lient_tls_cert_hash\x18\x02 \x01(\x0c\"\xe8\x01\n\x05Query\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12.\n\x0c\x63onfig_query\x18\x02 \x01(\x0b\x32\x16.discovery.ConfigQueryH\x00\x12\x34\n\npeer_query\x18\x03 \x01(\x0b\x32\x1e.discovery.PeerMembershipQueryH\x00\x12-\n\x08\x63\x63_query\x18\x04 \x01(\x0b\x32\x19.discovery.ChaincodeQueryH\x00\x12\x30\n\x0blocal_peers\x18\x05 \x01(\x0b\x32\x19.discovery.LocalPeerQueryH\x00\x42\x07\n\x05query\"\xd9\x01\n\x0bQueryResult\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x10.discovery.ErrorH\x00\x12\x30\n\rconfig_result\x18\x02 \x01(\x0b\x32\x17.discovery.ConfigResultH\x00\x12\x37\n\x0c\x63\x63_query_res\x18\x03 \x01(\x0b\x32\x1f.discovery.ChaincodeQueryResultH\x00\x12\x32\n\x07members\x18\x04 \x01(\x0b\x32\x1f.discovery.PeerMembershipResultH\x00\x42\x08\n\x06result\"\r\n\x0b\x43onfigQuery\"\x82\x02\n\x0c\x43onfigResult\x12/\n\x04msps\x18\x01 \x03(\x0b\x32!.discovery.ConfigResult.MspsEntry\x12\x37\n\x08orderers\x18\x02 \x03(\x0b\x32%.discovery.ConfigResult.OrderersEntry\x1a\x41\n\tMspsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.msp.FabricMSPConfig:\x02\x38\x01\x1a\x45\n\rOrderersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.discovery.Endpoints:\x02\x38\x01\"C\n\x13PeerMembershipQuery\x12,\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1c.discovery.ChaincodeInterest\"\xa2\x01\n\x14PeerMembershipResult\x12\x45\n\x0cpeers_by_org\x18\x01 \x03(\x0b\x32/.discovery.PeerMembershipResult.PeersByOrgEntry\x1a\x43\n\x0fPeersByOrgEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.discovery.Peers:\x02\x38\x01\"A\n\x0e\x43haincodeQuery\x12/\n\tinterests\x18\x01 \x03(\x0b\x32\x1c.discovery.ChaincodeInterest\"A\n\x11\x43haincodeInterest\x12,\n\nchaincodes\x18\x01 \x03(\x0b\x32\x18.discovery.ChaincodeCall\"7\n\rChaincodeCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\"I\n\x14\x43haincodeQueryResult\x12\x31\n\x07\x63ontent\x18\x01 \x03(\x0b\x32 .discovery.EndorsementDescriptor\"\x10\n\x0eLocalPeerQuery\"\xf0\x01\n\x15\x45ndorsementDescriptor\x12\x11\n\tchaincode\x18\x01 \x01(\t\x12T\n\x13\x65ndorsers_by_groups\x18\x02 \x03(\x0b\x32\x37.discovery.EndorsementDescriptor.EndorsersByGroupsEntry\x12\"\n\x07layouts\x18\x03 \x03(\x0b\x32\x11.discovery.Layout\x1aJ\n\x16\x45ndorsersByGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.discovery.Peers:\x02\x38\x01\"\x89\x01\n\x06Layout\x12\x45\n\x13quantities_by_group\x18\x01 \x03(\x0b\x32(.discovery.Layout.QuantitiesByGroupEntry\x1a\x38\n\x16QuantitiesByGroupEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\'\n\x05Peers\x12\x1e\n\x05peers\x18\x01 \x03(\x0b\x32\x0f.discovery.Peer\"i\n\x04Peer\x12$\n\nstate_info\x18\x01 \x01(\x0b\x32\x10.gossip.Envelope\x12)\n\x0fmembership_info\x18\x02 \x01(\x0b\x32\x10.gossip.Envelope\x12\x10\n\x08identity\x18\x03 \x01(\x0c\"\x18\n\x05\x45rror\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"2\n\tEndpoints\x12%\n\x08\x65ndpoint\x18\x01 \x03(\x0b\x32\x13.discovery.Endpoint\"&\n\x08\x45ndpoint\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r2H\n\tDiscovery\x12;\n\x08\x44iscover\x12\x18.discovery.SignedRequest\x1a\x13.discovery.Response\"\x00\x42\x30Z.github.com/hyperledger/fabric/protos/discoveryb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_gossip_dot_message__pb2.DESCRIPTOR,hfc_dot_protos_dot_msp_dot_msp__config__pb2.DESCRIPTOR,hfc_dot_protos_dot_msp_dot_identities__pb2.DESCRIPTOR,])




_SIGNEDREQUEST = _descriptor.Descriptor(
  name='SignedRequest',
  full_name='discovery.SignedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='discovery.SignedRequest.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='discovery.SignedRequest.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=200,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='discovery.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authentication', full_name='discovery.Request.authentication', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queries', full_name='discovery.Request.queries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=291,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='discovery.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='discovery.Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=344,
)


_AUTHINFO = _descriptor.Descriptor(
  name='AuthInfo',
  full_name='discovery.AuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_identity', full_name='discovery.AuthInfo.client_identity', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_tls_cert_hash', full_name='discovery.AuthInfo.client_tls_cert_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=411,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='discovery.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='discovery.Query.channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_query', full_name='discovery.Query.config_query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_query', full_name='discovery.Query.peer_query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cc_query', full_name='discovery.Query.cc_query', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_peers', full_name='discovery.Query.local_peers', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='discovery.Query.query',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=414,
  serialized_end=646,
)


_QUERYRESULT = _descriptor.Descriptor(
  name='QueryResult',
  full_name='discovery.QueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='discovery.QueryResult.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_result', full_name='discovery.QueryResult.config_result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cc_query_res', full_name='discovery.QueryResult.cc_query_res', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='discovery.QueryResult.members', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='discovery.QueryResult.result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=649,
  serialized_end=866,
)


_CONFIGQUERY = _descriptor.Descriptor(
  name='ConfigQuery',
  full_name='discovery.ConfigQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=881,
)


_CONFIGRESULT_MSPSENTRY = _descriptor.Descriptor(
  name='MspsEntry',
  full_name='discovery.ConfigResult.MspsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='discovery.ConfigResult.MspsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='discovery.ConfigResult.MspsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1071,
)

_CONFIGRESULT_ORDERERSENTRY = _descriptor.Descriptor(
  name='OrderersEntry',
  full_name='discovery.ConfigResult.OrderersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='discovery.ConfigResult.OrderersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='discovery.ConfigResult.OrderersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1142,
)

_CONFIGRESULT = _descriptor.Descriptor(
  name='ConfigResult',
  full_name='discovery.ConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msps', full_name='discovery.ConfigResult.msps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderers', full_name='discovery.ConfigResult.orderers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONFIGRESULT_MSPSENTRY, _CONFIGRESULT_ORDERERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=1142,
)


_PEERMEMBERSHIPQUERY = _descriptor.Descriptor(
  name='PeerMembershipQuery',
  full_name='discovery.PeerMembershipQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='discovery.PeerMembershipQuery.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1211,
)


_PEERMEMBERSHIPRESULT_PEERSBYORGENTRY = _descriptor.Descriptor(
  name='PeersByOrgEntry',
  full_name='discovery.PeerMembershipResult.PeersByOrgEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='discovery.PeerMembershipResult.PeersByOrgEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='discovery.PeerMembershipResult.PeersByOrgEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1376,
)

_PEERMEMBERSHIPRESULT = _descriptor.Descriptor(
  name='PeerMembershipResult',
  full_name='discovery.PeerMembershipResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers_by_org', full_name='discovery.PeerMembershipResult.peers_by_org', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PEERMEMBERSHIPRESULT_PEERSBYORGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1376,
)


_CHAINCODEQUERY = _descriptor.Descriptor(
  name='ChaincodeQuery',
  full_name='discovery.ChaincodeQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interests', full_name='discovery.ChaincodeQuery.interests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1443,
)


_CHAINCODEINTEREST = _descriptor.Descriptor(
  name='ChaincodeInterest',
  full_name='discovery.ChaincodeInterest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincodes', full_name='discovery.ChaincodeInterest.chaincodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1510,
)


_CHAINCODECALL = _descriptor.Descriptor(
  name='ChaincodeCall',
  full_name='discovery.ChaincodeCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='discovery.ChaincodeCall.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_names', full_name='discovery.ChaincodeCall.collection_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1567,
)


_CHAINCODEQUERYRESULT = _descriptor.Descriptor(
  name='ChaincodeQueryResult',
  full_name='discovery.ChaincodeQueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='discovery.ChaincodeQueryResult.content', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1569,
  serialized_end=1642,
)


_LOCALPEERQUERY = _descriptor.Descriptor(
  name='LocalPeerQuery',
  full_name='discovery.LocalPeerQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1660,
)


_ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY = _descriptor.Descriptor(
  name='EndorsersByGroupsEntry',
  full_name='discovery.EndorsementDescriptor.EndorsersByGroupsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='discovery.EndorsementDescriptor.EndorsersByGroupsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='discovery.EndorsementDescriptor.EndorsersByGroupsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1903,
)

_ENDORSEMENTDESCRIPTOR = _descriptor.Descriptor(
  name='EndorsementDescriptor',
  full_name='discovery.EndorsementDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincode', full_name='discovery.EndorsementDescriptor.chaincode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endorsers_by_groups', full_name='discovery.EndorsementDescriptor.endorsers_by_groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='layouts', full_name='discovery.EndorsementDescriptor.layouts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1663,
  serialized_end=1903,
)


_LAYOUT_QUANTITIESBYGROUPENTRY = _descriptor.Descriptor(
  name='QuantitiesByGroupEntry',
  full_name='discovery.Layout.QuantitiesByGroupEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='discovery.Layout.QuantitiesByGroupEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='discovery.Layout.QuantitiesByGroupEntry.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2043,
)

_LAYOUT = _descriptor.Descriptor(
  name='Layout',
  full_name='discovery.Layout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantities_by_group', full_name='discovery.Layout.quantities_by_group', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LAYOUT_QUANTITIESBYGROUPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1906,
  serialized_end=2043,
)


_PEERS = _descriptor.Descriptor(
  name='Peers',
  full_name='discovery.Peers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='discovery.Peers.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2045,
  serialized_end=2084,
)


_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='discovery.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_info', full_name='discovery.Peer.state_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='membership_info', full_name='discovery.Peer.membership_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identity', full_name='discovery.Peer.identity', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2191,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='discovery.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='discovery.Error.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2193,
  serialized_end=2217,
)


_ENDPOINTS = _descriptor.Descriptor(
  name='Endpoints',
  full_name='discovery.Endpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='discovery.Endpoints.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=2269,
)


_ENDPOINT = _descriptor.Descriptor(
  name='Endpoint',
  full_name='discovery.Endpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='discovery.Endpoint.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='discovery.Endpoint.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2271,
  serialized_end=2309,
)

_REQUEST.fields_by_name['authentication'].message_type = _AUTHINFO
_REQUEST.fields_by_name['queries'].message_type = _QUERY
_RESPONSE.fields_by_name['results'].message_type = _QUERYRESULT
_QUERY.fields_by_name['config_query'].message_type = _CONFIGQUERY
_QUERY.fields_by_name['peer_query'].message_type = _PEERMEMBERSHIPQUERY
_QUERY.fields_by_name['cc_query'].message_type = _CHAINCODEQUERY
_QUERY.fields_by_name['local_peers'].message_type = _LOCALPEERQUERY
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['config_query'])
_QUERY.fields_by_name['config_query'].containing_oneof = _QUERY.oneofs_by_name['query']
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['peer_query'])
_QUERY.fields_by_name['peer_query'].containing_oneof = _QUERY.oneofs_by_name['query']
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['cc_query'])
_QUERY.fields_by_name['cc_query'].containing_oneof = _QUERY.oneofs_by_name['query']
_QUERY.oneofs_by_name['query'].fields.append(
  _QUERY.fields_by_name['local_peers'])
_QUERY.fields_by_name['local_peers'].containing_oneof = _QUERY.oneofs_by_name['query']
_QUERYRESULT.fields_by_name['error'].message_type = _ERROR
_QUERYRESULT.fields_by_name['config_result'].message_type = _CONFIGRESULT
_QUERYRESULT.fields_by_name['cc_query_res'].message_type = _CHAINCODEQUERYRESULT
_QUERYRESULT.fields_by_name['members'].message_type = _PEERMEMBERSHIPRESULT
_QUERYRESULT.oneofs_by_name['result'].fields.append(
  _QUERYRESULT.fields_by_name['error'])
_QUERYRESULT.fields_by_name['error'].containing_oneof = _QUERYRESULT.oneofs_by_name['result']
_QUERYRESULT.oneofs_by_name['result'].fields.append(
  _QUERYRESULT.fields_by_name['config_result'])
_QUERYRESULT.fields_by_name['config_result'].containing_oneof = _QUERYRESULT.oneofs_by_name['result']
_QUERYRESULT.oneofs_by_name['result'].fields.append(
  _QUERYRESULT.fields_by_name['cc_query_res'])
_QUERYRESULT.fields_by_name['cc_query_res'].containing_oneof = _QUERYRESULT.oneofs_by_name['result']
_QUERYRESULT.oneofs_by_name['result'].fields.append(
  _QUERYRESULT.fields_by_name['members'])
_QUERYRESULT.fields_by_name['members'].containing_oneof = _QUERYRESULT.oneofs_by_name['result']
_CONFIGRESULT_MSPSENTRY.fields_by_name['value'].message_type = hfc_dot_protos_dot_msp_dot_msp__config__pb2._FABRICMSPCONFIG
_CONFIGRESULT_MSPSENTRY.containing_type = _CONFIGRESULT
_CONFIGRESULT_ORDERERSENTRY.fields_by_name['value'].message_type = _ENDPOINTS
_CONFIGRESULT_ORDERERSENTRY.containing_type = _CONFIGRESULT
_CONFIGRESULT.fields_by_name['msps'].message_type = _CONFIGRESULT_MSPSENTRY
_CONFIGRESULT.fields_by_name['orderers'].message_type = _CONFIGRESULT_ORDERERSENTRY
_PEERMEMBERSHIPQUERY.fields_by_name['filter'].message_type = _CHAINCODEINTEREST
_PEERMEMBERSHIPRESULT_PEERSBYORGENTRY.fields_by_name['value'].message_type = _PEERS
_PEERMEMBERSHIPRESULT_PEERSBYORGENTRY.containing_type = _PEERMEMBERSHIPRESULT
_PEERMEMBERSHIPRESULT.fields_by_name['peers_by_org'].message_type = _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY
_CHAINCODEQUERY.fields_by_name['interests'].message_type = _CHAINCODEINTEREST
_CHAINCODEINTEREST.fields_by_name['chaincodes'].message_type = _CHAINCODECALL
_CHAINCODEQUERYRESULT.fields_by_name['content'].message_type = _ENDORSEMENTDESCRIPTOR
_ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY.fields_by_name['value'].message_type = _PEERS
_ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY.containing_type = _ENDORSEMENTDESCRIPTOR
_ENDORSEMENTDESCRIPTOR.fields_by_name['endorsers_by_groups'].message_type = _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY
_ENDORSEMENTDESCRIPTOR.fields_by_name['layouts'].message_type = _LAYOUT
_LAYOUT_QUANTITIESBYGROUPENTRY.containing_type = _LAYOUT
_LAYOUT.fields_by_name['quantities_by_group'].message_type = _LAYOUT_QUANTITIESBYGROUPENTRY
_PEERS.fields_by_name['peers'].message_type = _PEER
_PEER.fields_by_name['state_info'].message_type = hfc_dot_protos_dot_gossip_dot_message__pb2._ENVELOPE
_PEER.fields_by_name['membership_info'].message_type = hfc_dot_protos_dot_gossip_dot_message__pb2._ENVELOPE
_ENDPOINTS.fields_by_name['endpoint'].message_type = _ENDPOINT
DESCRIPTOR.message_types_by_name['SignedRequest'] = _SIGNEDREQUEST
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['AuthInfo'] = _AUTHINFO
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['QueryResult'] = _QUERYRESULT
DESCRIPTOR.message_types_by_name['ConfigQuery'] = _CONFIGQUERY
DESCRIPTOR.message_types_by_name['ConfigResult'] = _CONFIGRESULT
DESCRIPTOR.message_types_by_name['PeerMembershipQuery'] = _PEERMEMBERSHIPQUERY
DESCRIPTOR.message_types_by_name['PeerMembershipResult'] = _PEERMEMBERSHIPRESULT
DESCRIPTOR.message_types_by_name['ChaincodeQuery'] = _CHAINCODEQUERY
DESCRIPTOR.message_types_by_name['ChaincodeInterest'] = _CHAINCODEINTEREST
DESCRIPTOR.message_types_by_name['ChaincodeCall'] = _CHAINCODECALL
DESCRIPTOR.message_types_by_name['ChaincodeQueryResult'] = _CHAINCODEQUERYRESULT
DESCRIPTOR.message_types_by_name['LocalPeerQuery'] = _LOCALPEERQUERY
DESCRIPTOR.message_types_by_name['EndorsementDescriptor'] = _ENDORSEMENTDESCRIPTOR
DESCRIPTOR.message_types_by_name['Layout'] = _LAYOUT
DESCRIPTOR.message_types_by_name['Peers'] = _PEERS
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Endpoints'] = _ENDPOINTS
DESCRIPTOR.message_types_by_name['Endpoint'] = _ENDPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignedRequest = _reflection.GeneratedProtocolMessageType('SignedRequest', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDREQUEST,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.SignedRequest)
  ))
_sym_db.RegisterMessage(SignedRequest)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(
  DESCRIPTOR = _REQUEST,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Request)
  ))
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Response)
  ))
_sym_db.RegisterMessage(Response)

AuthInfo = _reflection.GeneratedProtocolMessageType('AuthInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUTHINFO,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.AuthInfo)
  ))
_sym_db.RegisterMessage(AuthInfo)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), dict(
  DESCRIPTOR = _QUERY,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Query)
  ))
_sym_db.RegisterMessage(Query)

QueryResult = _reflection.GeneratedProtocolMessageType('QueryResult', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESULT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.QueryResult)
  ))
_sym_db.RegisterMessage(QueryResult)

ConfigQuery = _reflection.GeneratedProtocolMessageType('ConfigQuery', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGQUERY,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ConfigQuery)
  ))
_sym_db.RegisterMessage(ConfigQuery)

ConfigResult = _reflection.GeneratedProtocolMessageType('ConfigResult', (_message.Message,), dict(

  MspsEntry = _reflection.GeneratedProtocolMessageType('MspsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONFIGRESULT_MSPSENTRY,
    __module__ = 'hfc.protos.discovery.protocol_pb2'
    # @@protoc_insertion_point(class_scope:discovery.ConfigResult.MspsEntry)
    ))
  ,

  OrderersEntry = _reflection.GeneratedProtocolMessageType('OrderersEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONFIGRESULT_ORDERERSENTRY,
    __module__ = 'hfc.protos.discovery.protocol_pb2'
    # @@protoc_insertion_point(class_scope:discovery.ConfigResult.OrderersEntry)
    ))
  ,
  DESCRIPTOR = _CONFIGRESULT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ConfigResult)
  ))
_sym_db.RegisterMessage(ConfigResult)
_sym_db.RegisterMessage(ConfigResult.MspsEntry)
_sym_db.RegisterMessage(ConfigResult.OrderersEntry)

PeerMembershipQuery = _reflection.GeneratedProtocolMessageType('PeerMembershipQuery', (_message.Message,), dict(
  DESCRIPTOR = _PEERMEMBERSHIPQUERY,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.PeerMembershipQuery)
  ))
_sym_db.RegisterMessage(PeerMembershipQuery)

PeerMembershipResult = _reflection.GeneratedProtocolMessageType('PeerMembershipResult', (_message.Message,), dict(

  PeersByOrgEntry = _reflection.GeneratedProtocolMessageType('PeersByOrgEntry', (_message.Message,), dict(
    DESCRIPTOR = _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY,
    __module__ = 'hfc.protos.discovery.protocol_pb2'
    # @@protoc_insertion_point(class_scope:discovery.PeerMembershipResult.PeersByOrgEntry)
    ))
  ,
  DESCRIPTOR = _PEERMEMBERSHIPRESULT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.PeerMembershipResult)
  ))
_sym_db.RegisterMessage(PeerMembershipResult)
_sym_db.RegisterMessage(PeerMembershipResult.PeersByOrgEntry)

ChaincodeQuery = _reflection.GeneratedProtocolMessageType('ChaincodeQuery', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEQUERY,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ChaincodeQuery)
  ))
_sym_db.RegisterMessage(ChaincodeQuery)

ChaincodeInterest = _reflection.GeneratedProtocolMessageType('ChaincodeInterest', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEINTEREST,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ChaincodeInterest)
  ))
_sym_db.RegisterMessage(ChaincodeInterest)

ChaincodeCall = _reflection.GeneratedProtocolMessageType('ChaincodeCall', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODECALL,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ChaincodeCall)
  ))
_sym_db.RegisterMessage(ChaincodeCall)

ChaincodeQueryResult = _reflection.GeneratedProtocolMessageType('ChaincodeQueryResult', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEQUERYRESULT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.ChaincodeQueryResult)
  ))
_sym_db.RegisterMessage(ChaincodeQueryResult)

LocalPeerQuery = _reflection.GeneratedProtocolMessageType('LocalPeerQuery', (_message.Message,), dict(
  DESCRIPTOR = _LOCALPEERQUERY,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.LocalPeerQuery)
  ))
_sym_db.RegisterMessage(LocalPeerQuery)

EndorsementDescriptor = _reflection.GeneratedProtocolMessageType('EndorsementDescriptor', (_message.Message,), dict(

  EndorsersByGroupsEntry = _reflection.GeneratedProtocolMessageType('EndorsersByGroupsEntry', (_message.Message,), dict(
    DESCRIPTOR = _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY,
    __module__ = 'hfc.protos.discovery.protocol_pb2'
    # @@protoc_insertion_point(class_scope:discovery.EndorsementDescriptor.EndorsersByGroupsEntry)
    ))
  ,
  DESCRIPTOR = _ENDORSEMENTDESCRIPTOR,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.EndorsementDescriptor)
  ))
_sym_db.RegisterMessage(EndorsementDescriptor)
_sym_db.RegisterMessage(EndorsementDescriptor.EndorsersByGroupsEntry)

Layout = _reflection.GeneratedProtocolMessageType('Layout', (_message.Message,), dict(

  QuantitiesByGroupEntry = _reflection.GeneratedProtocolMessageType('QuantitiesByGroupEntry', (_message.Message,), dict(
    DESCRIPTOR = _LAYOUT_QUANTITIESBYGROUPENTRY,
    __module__ = 'hfc.protos.discovery.protocol_pb2'
    # @@protoc_insertion_point(class_scope:discovery.Layout.QuantitiesByGroupEntry)
    ))
  ,
  DESCRIPTOR = _LAYOUT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Layout)
  ))
_sym_db.RegisterMessage(Layout)
_sym_db.RegisterMessage(Layout.QuantitiesByGroupEntry)

Peers = _reflection.GeneratedProtocolMessageType('Peers', (_message.Message,), dict(
  DESCRIPTOR = _PEERS,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Peers)
  ))
_sym_db.RegisterMessage(Peers)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), dict(
  DESCRIPTOR = _PEER,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Peer)
  ))
_sym_db.RegisterMessage(Peer)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Error)
  ))
_sym_db.RegisterMessage(Error)

Endpoints = _reflection.GeneratedProtocolMessageType('Endpoints', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINTS,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Endpoints)
  ))
_sym_db.RegisterMessage(Endpoints)

Endpoint = _reflection.GeneratedProtocolMessageType('Endpoint', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINT,
  __module__ = 'hfc.protos.discovery.protocol_pb2'
  # @@protoc_insertion_point(class_scope:discovery.Endpoint)
  ))
_sym_db.RegisterMessage(Endpoint)


DESCRIPTOR._options = None
_CONFIGRESULT_MSPSENTRY._options = None
_CONFIGRESULT_ORDERERSENTRY._options = None
_PEERMEMBERSHIPRESULT_PEERSBYORGENTRY._options = None
_ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY._options = None
_LAYOUT_QUANTITIESBYGROUPENTRY._options = None

_DISCOVERY = _descriptor.ServiceDescriptor(
  name='Discovery',
  full_name='discovery.Discovery',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2311,
  serialized_end=2383,
  methods=[
  _descriptor.MethodDescriptor(
    name='Discover',
    full_name='discovery.Discovery.Discover',
    index=0,
    containing_service=None,
    input_type=_SIGNEDREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISCOVERY)

DESCRIPTOR.services_by_name['Discovery'] = _DISCOVERY

# @@protoc_insertion_point(module_scope)
