# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from hfc.protos.common import common_pb2 as hfc_dot_protos_dot_common_dot_common__pb2
from hfc.protos.peer import admin_pb2 as hfc_dot_protos_dot_peer_dot_admin__pb2


class AdminStub(object):
  """Interface exported by the server.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetStatus = channel.unary_unary(
        '/protos.Admin/GetStatus',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.ServerStatus.FromString,
        )
    self.StartServer = channel.unary_unary(
        '/protos.Admin/StartServer',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.ServerStatus.FromString,
        )
    self.GetModuleLogLevel = channel.unary_unary(
        '/protos.Admin/GetModuleLogLevel',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogLevelResponse.FromString,
        )
    self.SetModuleLogLevel = channel.unary_unary(
        '/protos.Admin/SetModuleLogLevel',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogLevelResponse.FromString,
        )
    self.RevertLogLevels = channel.unary_unary(
        '/protos.Admin/RevertLogLevels',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetLogSpec = channel.unary_unary(
        '/protos.Admin/GetLogSpec',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogSpecResponse.FromString,
        )
    self.SetLogSpec = channel.unary_unary(
        '/protos.Admin/SetLogSpec',
        request_serializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.SerializeToString,
        response_deserializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogSpecResponse.FromString,
        )


class AdminServicer(object):
  """Interface exported by the server.
  """

  def GetStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartServer(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModuleLogLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetModuleLogLevel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevertLogLevels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLogSpec(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetLogSpec(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdminServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetStatus': grpc.unary_unary_rpc_method_handler(
          servicer.GetStatus,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.ServerStatus.SerializeToString,
      ),
      'StartServer': grpc.unary_unary_rpc_method_handler(
          servicer.StartServer,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.ServerStatus.SerializeToString,
      ),
      'GetModuleLogLevel': grpc.unary_unary_rpc_method_handler(
          servicer.GetModuleLogLevel,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogLevelResponse.SerializeToString,
      ),
      'SetModuleLogLevel': grpc.unary_unary_rpc_method_handler(
          servicer.SetModuleLogLevel,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogLevelResponse.SerializeToString,
      ),
      'RevertLogLevels': grpc.unary_unary_rpc_method_handler(
          servicer.RevertLogLevels,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetLogSpec': grpc.unary_unary_rpc_method_handler(
          servicer.GetLogSpec,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogSpecResponse.SerializeToString,
      ),
      'SetLogSpec': grpc.unary_unary_rpc_method_handler(
          servicer.SetLogSpec,
          request_deserializer=hfc_dot_protos_dot_common_dot_common__pb2.Envelope.FromString,
          response_serializer=hfc_dot_protos_dot_peer_dot_admin__pb2.LogSpecResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'protos.Admin', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
