# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/token/prover.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from hfc.protos.token import expectations_pb2 as hfc_dot_protos_dot_token_dot_expectations__pb2
from hfc.protos.token import transaction_pb2 as hfc_dot_protos_dot_token_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/token/prover.proto',
  package='token',
  syntax='proto3',
  serialized_options=_b('\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/token'),
  serialized_pb=_b('\n\x1dhfc/protos/token/prover.proto\x12\x05token\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#hfc/protos/token/expectations.proto\x1a\"hfc/protos/token/transaction.proto\"A\n\x0cTokenToIssue\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x04\"=\n\x16RecipientTransferShare\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x10\n\x08quantity\x18\x02 \x01(\x04\"I\n\x0bTokenOutput\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.token.InputId\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x04\"3\n\rUnspentTokens\x12\"\n\x06tokens\x18\x01 \x03(\x0b\x32\x12.token.TokenOutput\"!\n\x0bListRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\"Q\n\rImportRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12,\n\x0ftokens_to_issue\x18\x02 \x03(\x0b\x32\x13.token.TokenToIssue\"w\n\x0fTransferRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12!\n\ttoken_ids\x18\x02 \x03(\x0b\x32\x0e.token.InputId\x12-\n\x06shares\x18\x03 \x03(\x0b\x32\x1d.token.RecipientTransferShare\"b\n\rRedeemRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12!\n\ttoken_ids\x18\x02 \x03(\x0b\x32\x0e.token.InputId\x12\x1a\n\x12quantity_to_redeem\x18\x03 \x01(\x04\">\n\x17\x41llowanceRecipientShare\x12\x11\n\trecipient\x18\x01 \x01(\x0c\x12\x10\n\x08quantity\x18\x02 \x01(\x04\"\x81\x01\n\x0e\x41pproveRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x38\n\x10\x61llowance_shares\x18\x02 \x03(\x0b\x32\x1e.token.AllowanceRecipientShare\x12!\n\ttoken_ids\x18\x03 \x03(\x0b\x32\x0e.token.InputId\"y\n\x12\x45xpectationRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12,\n\x0b\x65xpectation\x18\x02 \x01(\x0b\x32\x17.token.TokenExpectation\x12!\n\ttoken_ids\x18\x03 \x03(\x0b\x32\x0e.token.InputId\"\x82\x01\n\x06Header\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x04 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x05 \x01(\x0c\"\x98\x03\n\x07\x43ommand\x12\x1d\n\x06header\x18\x01 \x01(\x0b\x32\r.token.Header\x12.\n\x0eimport_request\x18\x02 \x01(\x0b\x32\x14.token.ImportRequestH\x00\x12\x32\n\x10transfer_request\x18\x03 \x01(\x0b\x32\x16.token.TransferRequestH\x00\x12*\n\x0clist_request\x18\x04 \x01(\x0b\x32\x12.token.ListRequestH\x00\x12.\n\x0eredeem_request\x18\x05 \x01(\x0b\x32\x14.token.RedeemRequestH\x00\x12\x30\n\x0f\x61pprove_request\x18\x06 \x01(\x0b\x32\x15.token.ApproveRequestH\x00\x12\x37\n\x15transfer_from_request\x18\x07 \x01(\x0b\x32\x16.token.TransferRequestH\x00\x12\x38\n\x13\x65xpectation_request\x18\x08 \x01(\x0b\x32\x19.token.ExpectationRequestH\x00\x42\t\n\x07payload\"3\n\rSignedCommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"m\n\x15\x43ommandResponseHeader\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63ommand_hash\x18\x02 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x0c\")\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"\xcd\x01\n\x0f\x43ommandResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.token.CommandResponseHeader\x12\x1b\n\x03\x65rr\x18\x02 \x01(\x0b\x32\x0c.token.ErrorH\x00\x12\x34\n\x11token_transaction\x18\x03 \x01(\x0b\x32\x17.token.TokenTransactionH\x00\x12.\n\x0eunspent_tokens\x18\x04 \x01(\x0b\x32\x14.token.UnspentTokensH\x00\x42\t\n\x07payload\"<\n\x15SignedCommandResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x32P\n\x06Prover\x12\x46\n\x0eProcessCommand\x12\x14.token.SignedCommand\x1a\x1c.token.SignedCommandResponse\"\x00\x42Q\n#org.hyperledger.fabric.protos.tokenZ*github.com/hyperledger/fabric/protos/tokenb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_expectations__pb2.DESCRIPTOR,hfc_dot_protos_dot_token_dot_transaction__pb2.DESCRIPTOR,])




_TOKENTOISSUE = _descriptor.Descriptor(
  name='TokenToIssue',
  full_name='token.TokenToIssue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.TokenToIssue.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.TokenToIssue.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.TokenToIssue.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=211,
)


_RECIPIENTTRANSFERSHARE = _descriptor.Descriptor(
  name='RecipientTransferShare',
  full_name='token.RecipientTransferShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.RecipientTransferShare.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.RecipientTransferShare.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=274,
)


_TOKENOUTPUT = _descriptor.Descriptor(
  name='TokenOutput',
  full_name='token.TokenOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='token.TokenOutput.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='token.TokenOutput.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.TokenOutput.quantity', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=349,
)


_UNSPENTTOKENS = _descriptor.Descriptor(
  name='UnspentTokens',
  full_name='token.UnspentTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='token.UnspentTokens.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=402,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='token.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ListRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=437,
)


_IMPORTREQUEST = _descriptor.Descriptor(
  name='ImportRequest',
  full_name='token.ImportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ImportRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokens_to_issue', full_name='token.ImportRequest.tokens_to_issue', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=520,
)


_TRANSFERREQUEST = _descriptor.Descriptor(
  name='TransferRequest',
  full_name='token.TransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.TransferRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.TransferRequest.token_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shares', full_name='token.TransferRequest.shares', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=641,
)


_REDEEMREQUEST = _descriptor.Descriptor(
  name='RedeemRequest',
  full_name='token.RedeemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.RedeemRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.RedeemRequest.token_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_to_redeem', full_name='token.RedeemRequest.quantity_to_redeem', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=741,
)


_ALLOWANCERECIPIENTSHARE = _descriptor.Descriptor(
  name='AllowanceRecipientShare',
  full_name='token.AllowanceRecipientShare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient', full_name='token.AllowanceRecipientShare.recipient', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='token.AllowanceRecipientShare.quantity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=805,
)


_APPROVEREQUEST = _descriptor.Descriptor(
  name='ApproveRequest',
  full_name='token.ApproveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ApproveRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowance_shares', full_name='token.ApproveRequest.allowance_shares', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.ApproveRequest.token_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=937,
)


_EXPECTATIONREQUEST = _descriptor.Descriptor(
  name='ExpectationRequest',
  full_name='token.ExpectationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='credential', full_name='token.ExpectationRequest.credential', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectation', full_name='token.ExpectationRequest.expectation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_ids', full_name='token.ExpectationRequest.token_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1060,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='token.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='token.Header.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='token.Header.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='token.Header.nonce', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='token.Header.creator', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cert_hash', full_name='token.Header.tls_cert_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1193,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='token.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='token.Command.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_request', full_name='token.Command.import_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_request', full_name='token.Command.transfer_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_request', full_name='token.Command.list_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redeem_request', full_name='token.Command.redeem_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approve_request', full_name='token.Command.approve_request', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_from_request', full_name='token.Command.transfer_from_request', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expectation_request', full_name='token.Command.expectation_request', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.Command.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1196,
  serialized_end=1604,
)


_SIGNEDCOMMAND = _descriptor.Descriptor(
  name='SignedCommand',
  full_name='token.SignedCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='token.SignedCommand.command', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='token.SignedCommand.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1606,
  serialized_end=1657,
)


_COMMANDRESPONSEHEADER = _descriptor.Descriptor(
  name='CommandResponseHeader',
  full_name='token.CommandResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='token.CommandResponseHeader.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_hash', full_name='token.CommandResponseHeader.command_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='token.CommandResponseHeader.creator', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1768,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='token.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='token.Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='token.Error.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=1811,
)


_COMMANDRESPONSE = _descriptor.Descriptor(
  name='CommandResponse',
  full_name='token.CommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='token.CommandResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='err', full_name='token.CommandResponse.err', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_transaction', full_name='token.CommandResponse.token_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unspent_tokens', full_name='token.CommandResponse.unspent_tokens', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='token.CommandResponse.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1814,
  serialized_end=2019,
)


_SIGNEDCOMMANDRESPONSE = _descriptor.Descriptor(
  name='SignedCommandResponse',
  full_name='token.SignedCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='token.SignedCommandResponse.response', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='token.SignedCommandResponse.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2081,
)

_TOKENOUTPUT.fields_by_name['id'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_UNSPENTTOKENS.fields_by_name['tokens'].message_type = _TOKENOUTPUT
_IMPORTREQUEST.fields_by_name['tokens_to_issue'].message_type = _TOKENTOISSUE
_TRANSFERREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_TRANSFERREQUEST.fields_by_name['shares'].message_type = _RECIPIENTTRANSFERSHARE
_REDEEMREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_APPROVEREQUEST.fields_by_name['allowance_shares'].message_type = _ALLOWANCERECIPIENTSHARE
_APPROVEREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_EXPECTATIONREQUEST.fields_by_name['expectation'].message_type = hfc_dot_protos_dot_token_dot_expectations__pb2._TOKENEXPECTATION
_EXPECTATIONREQUEST.fields_by_name['token_ids'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._INPUTID
_HEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMAND.fields_by_name['header'].message_type = _HEADER
_COMMAND.fields_by_name['import_request'].message_type = _IMPORTREQUEST
_COMMAND.fields_by_name['transfer_request'].message_type = _TRANSFERREQUEST
_COMMAND.fields_by_name['list_request'].message_type = _LISTREQUEST
_COMMAND.fields_by_name['redeem_request'].message_type = _REDEEMREQUEST
_COMMAND.fields_by_name['approve_request'].message_type = _APPROVEREQUEST
_COMMAND.fields_by_name['transfer_from_request'].message_type = _TRANSFERREQUEST
_COMMAND.fields_by_name['expectation_request'].message_type = _EXPECTATIONREQUEST
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['import_request'])
_COMMAND.fields_by_name['import_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['transfer_request'])
_COMMAND.fields_by_name['transfer_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['list_request'])
_COMMAND.fields_by_name['list_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['redeem_request'])
_COMMAND.fields_by_name['redeem_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['approve_request'])
_COMMAND.fields_by_name['approve_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['transfer_from_request'])
_COMMAND.fields_by_name['transfer_from_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMAND.oneofs_by_name['payload'].fields.append(
  _COMMAND.fields_by_name['expectation_request'])
_COMMAND.fields_by_name['expectation_request'].containing_oneof = _COMMAND.oneofs_by_name['payload']
_COMMANDRESPONSEHEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDRESPONSE.fields_by_name['header'].message_type = _COMMANDRESPONSEHEADER
_COMMANDRESPONSE.fields_by_name['err'].message_type = _ERROR
_COMMANDRESPONSE.fields_by_name['token_transaction'].message_type = hfc_dot_protos_dot_token_dot_transaction__pb2._TOKENTRANSACTION
_COMMANDRESPONSE.fields_by_name['unspent_tokens'].message_type = _UNSPENTTOKENS
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['err'])
_COMMANDRESPONSE.fields_by_name['err'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['token_transaction'])
_COMMANDRESPONSE.fields_by_name['token_transaction'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
_COMMANDRESPONSE.oneofs_by_name['payload'].fields.append(
  _COMMANDRESPONSE.fields_by_name['unspent_tokens'])
_COMMANDRESPONSE.fields_by_name['unspent_tokens'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TokenToIssue'] = _TOKENTOISSUE
DESCRIPTOR.message_types_by_name['RecipientTransferShare'] = _RECIPIENTTRANSFERSHARE
DESCRIPTOR.message_types_by_name['TokenOutput'] = _TOKENOUTPUT
DESCRIPTOR.message_types_by_name['UnspentTokens'] = _UNSPENTTOKENS
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['ImportRequest'] = _IMPORTREQUEST
DESCRIPTOR.message_types_by_name['TransferRequest'] = _TRANSFERREQUEST
DESCRIPTOR.message_types_by_name['RedeemRequest'] = _REDEEMREQUEST
DESCRIPTOR.message_types_by_name['AllowanceRecipientShare'] = _ALLOWANCERECIPIENTSHARE
DESCRIPTOR.message_types_by_name['ApproveRequest'] = _APPROVEREQUEST
DESCRIPTOR.message_types_by_name['ExpectationRequest'] = _EXPECTATIONREQUEST
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['SignedCommand'] = _SIGNEDCOMMAND
DESCRIPTOR.message_types_by_name['CommandResponseHeader'] = _COMMANDRESPONSEHEADER
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['CommandResponse'] = _COMMANDRESPONSE
DESCRIPTOR.message_types_by_name['SignedCommandResponse'] = _SIGNEDCOMMANDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TokenToIssue = _reflection.GeneratedProtocolMessageType('TokenToIssue', (_message.Message,), dict(
  DESCRIPTOR = _TOKENTOISSUE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenToIssue)
  ))
_sym_db.RegisterMessage(TokenToIssue)

RecipientTransferShare = _reflection.GeneratedProtocolMessageType('RecipientTransferShare', (_message.Message,), dict(
  DESCRIPTOR = _RECIPIENTTRANSFERSHARE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.RecipientTransferShare)
  ))
_sym_db.RegisterMessage(RecipientTransferShare)

TokenOutput = _reflection.GeneratedProtocolMessageType('TokenOutput', (_message.Message,), dict(
  DESCRIPTOR = _TOKENOUTPUT,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TokenOutput)
  ))
_sym_db.RegisterMessage(TokenOutput)

UnspentTokens = _reflection.GeneratedProtocolMessageType('UnspentTokens', (_message.Message,), dict(
  DESCRIPTOR = _UNSPENTTOKENS,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.UnspentTokens)
  ))
_sym_db.RegisterMessage(UnspentTokens)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

ImportRequest = _reflection.GeneratedProtocolMessageType('ImportRequest', (_message.Message,), dict(
  DESCRIPTOR = _IMPORTREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ImportRequest)
  ))
_sym_db.RegisterMessage(ImportRequest)

TransferRequest = _reflection.GeneratedProtocolMessageType('TransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFERREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.TransferRequest)
  ))
_sym_db.RegisterMessage(TransferRequest)

RedeemRequest = _reflection.GeneratedProtocolMessageType('RedeemRequest', (_message.Message,), dict(
  DESCRIPTOR = _REDEEMREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.RedeemRequest)
  ))
_sym_db.RegisterMessage(RedeemRequest)

AllowanceRecipientShare = _reflection.GeneratedProtocolMessageType('AllowanceRecipientShare', (_message.Message,), dict(
  DESCRIPTOR = _ALLOWANCERECIPIENTSHARE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.AllowanceRecipientShare)
  ))
_sym_db.RegisterMessage(AllowanceRecipientShare)

ApproveRequest = _reflection.GeneratedProtocolMessageType('ApproveRequest', (_message.Message,), dict(
  DESCRIPTOR = _APPROVEREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ApproveRequest)
  ))
_sym_db.RegisterMessage(ApproveRequest)

ExpectationRequest = _reflection.GeneratedProtocolMessageType('ExpectationRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXPECTATIONREQUEST,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.ExpectationRequest)
  ))
_sym_db.RegisterMessage(ExpectationRequest)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Header)
  ))
_sym_db.RegisterMessage(Header)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Command)
  ))
_sym_db.RegisterMessage(Command)

SignedCommand = _reflection.GeneratedProtocolMessageType('SignedCommand', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDCOMMAND,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.SignedCommand)
  ))
_sym_db.RegisterMessage(SignedCommand)

CommandResponseHeader = _reflection.GeneratedProtocolMessageType('CommandResponseHeader', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESPONSEHEADER,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.CommandResponseHeader)
  ))
_sym_db.RegisterMessage(CommandResponseHeader)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.Error)
  ))
_sym_db.RegisterMessage(Error)

CommandResponse = _reflection.GeneratedProtocolMessageType('CommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESPONSE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.CommandResponse)
  ))
_sym_db.RegisterMessage(CommandResponse)

SignedCommandResponse = _reflection.GeneratedProtocolMessageType('SignedCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDCOMMANDRESPONSE,
  __module__ = 'hfc.protos.token.prover_pb2'
  # @@protoc_insertion_point(class_scope:token.SignedCommandResponse)
  ))
_sym_db.RegisterMessage(SignedCommandResponse)


DESCRIPTOR._options = None

_PROVER = _descriptor.ServiceDescriptor(
  name='Prover',
  full_name='token.Prover',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2083,
  serialized_end=2163,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessCommand',
    full_name='token.Prover.ProcessCommand',
    index=0,
    containing_service=None,
    input_type=_SIGNEDCOMMAND,
    output_type=_SIGNEDCOMMANDRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROVER)

DESCRIPTOR.services_by_name['Prover'] = _PROVER

# @@protoc_insertion_point(module_scope)
