# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/lifecycle/lifecycle.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/lifecycle/lifecycle.proto',
  package='lifecycle',
  syntax='proto3',
  serialized_options=_b('\n,org.hyperledger.fabric.protos.peer.lifecycleZ3github.com/hyperledger/fabric/protos/peer/lifecycle'),
  serialized_pb=_b('\n)hfc/protos/peer/lifecycle/lifecycle.proto\x12\tlifecycle\"X\n\x14InstallChaincodeArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12!\n\x19\x63haincode_install_package\x18\x03 \x01(\x0c\"&\n\x16InstallChaincodeResult\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\"<\n\x1bQueryInstalledChaincodeArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"-\n\x1dQueryInstalledChaincodeResult\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x42\x63\n,org.hyperledger.fabric.protos.peer.lifecycleZ3github.com/hyperledger/fabric/protos/peer/lifecycleb\x06proto3')
)




_INSTALLCHAINCODEARGS = _descriptor.Descriptor(
  name='InstallChaincodeArgs',
  full_name='lifecycle.InstallChaincodeArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='lifecycle.InstallChaincodeArgs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='lifecycle.InstallChaincodeArgs.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chaincode_install_package', full_name='lifecycle.InstallChaincodeArgs.chaincode_install_package', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=144,
)


_INSTALLCHAINCODERESULT = _descriptor.Descriptor(
  name='InstallChaincodeResult',
  full_name='lifecycle.InstallChaincodeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='lifecycle.InstallChaincodeResult.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=184,
)


_QUERYINSTALLEDCHAINCODEARGS = _descriptor.Descriptor(
  name='QueryInstalledChaincodeArgs',
  full_name='lifecycle.QueryInstalledChaincodeArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='lifecycle.QueryInstalledChaincodeArgs.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='lifecycle.QueryInstalledChaincodeArgs.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=246,
)


_QUERYINSTALLEDCHAINCODERESULT = _descriptor.Descriptor(
  name='QueryInstalledChaincodeResult',
  full_name='lifecycle.QueryInstalledChaincodeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='lifecycle.QueryInstalledChaincodeResult.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=293,
)

DESCRIPTOR.message_types_by_name['InstallChaincodeArgs'] = _INSTALLCHAINCODEARGS
DESCRIPTOR.message_types_by_name['InstallChaincodeResult'] = _INSTALLCHAINCODERESULT
DESCRIPTOR.message_types_by_name['QueryInstalledChaincodeArgs'] = _QUERYINSTALLEDCHAINCODEARGS
DESCRIPTOR.message_types_by_name['QueryInstalledChaincodeResult'] = _QUERYINSTALLEDCHAINCODERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstallChaincodeArgs = _reflection.GeneratedProtocolMessageType('InstallChaincodeArgs', (_message.Message,), dict(
  DESCRIPTOR = _INSTALLCHAINCODEARGS,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.InstallChaincodeArgs)
  ))
_sym_db.RegisterMessage(InstallChaincodeArgs)

InstallChaincodeResult = _reflection.GeneratedProtocolMessageType('InstallChaincodeResult', (_message.Message,), dict(
  DESCRIPTOR = _INSTALLCHAINCODERESULT,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.InstallChaincodeResult)
  ))
_sym_db.RegisterMessage(InstallChaincodeResult)

QueryInstalledChaincodeArgs = _reflection.GeneratedProtocolMessageType('QueryInstalledChaincodeArgs', (_message.Message,), dict(
  DESCRIPTOR = _QUERYINSTALLEDCHAINCODEARGS,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.QueryInstalledChaincodeArgs)
  ))
_sym_db.RegisterMessage(QueryInstalledChaincodeArgs)

QueryInstalledChaincodeResult = _reflection.GeneratedProtocolMessageType('QueryInstalledChaincodeResult', (_message.Message,), dict(
  DESCRIPTOR = _QUERYINSTALLEDCHAINCODERESULT,
  __module__ = 'hfc.protos.peer.lifecycle.lifecycle_pb2'
  # @@protoc_insertion_point(class_scope:lifecycle.QueryInstalledChaincodeResult)
  ))
_sym_db.RegisterMessage(QueryInstalledChaincodeResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
