# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/ledger/rwset/rwset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/ledger/rwset/rwset.proto',
  package='rwset',
  syntax='proto3',
  serialized_pb=_b('\n#hfc/protos/ledger/rwset/rwset.proto\x12\x05rwset\"\x83\x01\n\x0eTxReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12\'\n\x08ns_rwset\x18\x02 \x03(\x0b\x32\x15.rwset.NsReadWriteSet\"\x13\n\tDataModel\x12\x06\n\x02KV\x10\x00\"x\n\x0eNsReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x12\x44\n\x17\x63ollection_hashed_rwset\x18\x03 \x03(\x0b\x32#.rwset.CollectionHashedReadWriteSet\"e\n\x1c\x43ollectionHashedReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x14\n\x0chashed_rwset\x18\x02 \x01(\x0c\x12\x16\n\x0epvt_rwset_hash\x18\x03 \x01(\x0c\"x\n\x11TxPvtReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12.\n\x0cns_pvt_rwset\x18\x02 \x03(\x0b\x32\x18.rwset.NsPvtReadWriteSet\"f\n\x11NsPvtReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12>\n\x14\x63ollection_pvt_rwset\x18\x02 \x03(\x0b\x32 .rwset.CollectionPvtReadWriteSet\"C\n\x19\x43ollectionPvtReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x42_\n*org.hyperledger.fabric.protos.ledger.rwsetZ1github.com/hyperledger/fabric/protos/ledger/rwsetb\x06proto3')
)



_TXREADWRITESET_DATAMODEL = _descriptor.EnumDescriptor(
  name='DataModel',
  full_name='rwset.TxReadWriteSet.DataModel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KV', index=0, number=0,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=159,
  serialized_end=178,
)
_sym_db.RegisterEnumDescriptor(_TXREADWRITESET_DATAMODEL)


_TXREADWRITESET = _descriptor.Descriptor(
  name='TxReadWriteSet',
  full_name='rwset.TxReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_model', full_name='rwset.TxReadWriteSet.data_model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_rwset', full_name='rwset.TxReadWriteSet.ns_rwset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TXREADWRITESET_DATAMODEL,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=178,
)


_NSREADWRITESET = _descriptor.Descriptor(
  name='NsReadWriteSet',
  full_name='rwset.NsReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='rwset.NsReadWriteSet.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rwset', full_name='rwset.NsReadWriteSet.rwset', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_hashed_rwset', full_name='rwset.NsReadWriteSet.collection_hashed_rwset', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=300,
)


_COLLECTIONHASHEDREADWRITESET = _descriptor.Descriptor(
  name='CollectionHashedReadWriteSet',
  full_name='rwset.CollectionHashedReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='rwset.CollectionHashedReadWriteSet.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashed_rwset', full_name='rwset.CollectionHashedReadWriteSet.hashed_rwset', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pvt_rwset_hash', full_name='rwset.CollectionHashedReadWriteSet.pvt_rwset_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=403,
)


_TXPVTREADWRITESET = _descriptor.Descriptor(
  name='TxPvtReadWriteSet',
  full_name='rwset.TxPvtReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_model', full_name='rwset.TxPvtReadWriteSet.data_model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_pvt_rwset', full_name='rwset.TxPvtReadWriteSet.ns_pvt_rwset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=525,
)


_NSPVTREADWRITESET = _descriptor.Descriptor(
  name='NsPvtReadWriteSet',
  full_name='rwset.NsPvtReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='rwset.NsPvtReadWriteSet.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_pvt_rwset', full_name='rwset.NsPvtReadWriteSet.collection_pvt_rwset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=629,
)


_COLLECTIONPVTREADWRITESET = _descriptor.Descriptor(
  name='CollectionPvtReadWriteSet',
  full_name='rwset.CollectionPvtReadWriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='rwset.CollectionPvtReadWriteSet.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rwset', full_name='rwset.CollectionPvtReadWriteSet.rwset', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=698,
)

_TXREADWRITESET.fields_by_name['data_model'].enum_type = _TXREADWRITESET_DATAMODEL
_TXREADWRITESET.fields_by_name['ns_rwset'].message_type = _NSREADWRITESET
_TXREADWRITESET_DATAMODEL.containing_type = _TXREADWRITESET
_NSREADWRITESET.fields_by_name['collection_hashed_rwset'].message_type = _COLLECTIONHASHEDREADWRITESET
_TXPVTREADWRITESET.fields_by_name['data_model'].enum_type = _TXREADWRITESET_DATAMODEL
_TXPVTREADWRITESET.fields_by_name['ns_pvt_rwset'].message_type = _NSPVTREADWRITESET
_NSPVTREADWRITESET.fields_by_name['collection_pvt_rwset'].message_type = _COLLECTIONPVTREADWRITESET
DESCRIPTOR.message_types_by_name['TxReadWriteSet'] = _TXREADWRITESET
DESCRIPTOR.message_types_by_name['NsReadWriteSet'] = _NSREADWRITESET
DESCRIPTOR.message_types_by_name['CollectionHashedReadWriteSet'] = _COLLECTIONHASHEDREADWRITESET
DESCRIPTOR.message_types_by_name['TxPvtReadWriteSet'] = _TXPVTREADWRITESET
DESCRIPTOR.message_types_by_name['NsPvtReadWriteSet'] = _NSPVTREADWRITESET
DESCRIPTOR.message_types_by_name['CollectionPvtReadWriteSet'] = _COLLECTIONPVTREADWRITESET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TxReadWriteSet = _reflection.GeneratedProtocolMessageType('TxReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _TXREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.TxReadWriteSet)
  ))
_sym_db.RegisterMessage(TxReadWriteSet)

NsReadWriteSet = _reflection.GeneratedProtocolMessageType('NsReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _NSREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.NsReadWriteSet)
  ))
_sym_db.RegisterMessage(NsReadWriteSet)

CollectionHashedReadWriteSet = _reflection.GeneratedProtocolMessageType('CollectionHashedReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONHASHEDREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.CollectionHashedReadWriteSet)
  ))
_sym_db.RegisterMessage(CollectionHashedReadWriteSet)

TxPvtReadWriteSet = _reflection.GeneratedProtocolMessageType('TxPvtReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _TXPVTREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.TxPvtReadWriteSet)
  ))
_sym_db.RegisterMessage(TxPvtReadWriteSet)

NsPvtReadWriteSet = _reflection.GeneratedProtocolMessageType('NsPvtReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _NSPVTREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.NsPvtReadWriteSet)
  ))
_sym_db.RegisterMessage(NsPvtReadWriteSet)

CollectionPvtReadWriteSet = _reflection.GeneratedProtocolMessageType('CollectionPvtReadWriteSet', (_message.Message,), dict(
  DESCRIPTOR = _COLLECTIONPVTREADWRITESET,
  __module__ = 'hfc.protos.ledger.rwset.rwset_pb2'
  # @@protoc_insertion_point(class_scope:rwset.CollectionPvtReadWriteSet)
  ))
_sym_db.RegisterMessage(CollectionPvtReadWriteSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n*org.hyperledger.fabric.protos.ledger.rwsetZ1github.com/hyperledger/fabric/protos/ledger/rwset'))
# @@protoc_insertion_point(module_scope)
