# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/gossip/message.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.common import collection_pb2 as hfc_dot_protos_dot_common_dot_collection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/gossip/message.proto',
  package='gossip',
  syntax='proto3',
  serialized_options=_b('Z+github.com/hyperledger/fabric/protos/gossip'),
  serialized_pb=_b('\n\x1fhfc/protos/gossip/message.proto\x12\x06gossip\x1a\"hfc/protos/common/collection.proto\"_\n\x08\x45nvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12/\n\x0fsecret_envelope\x18\x03 \x01(\x0b\x32\x16.gossip.SecretEnvelope\"4\n\x0eSecretEnvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"/\n\x06Secret\x12\x1a\n\x10internalEndpoint\x18\x01 \x01(\tH\x00\x42\t\n\x07\x63ontent\"\x8d\t\n\rGossipMessage\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x0c\x12&\n\x03tag\x18\x03 \x01(\x0e\x32\x19.gossip.GossipMessage.Tag\x12)\n\talive_msg\x18\x05 \x01(\x0b\x32\x14.gossip.AliveMessageH\x00\x12,\n\x07mem_req\x18\x06 \x01(\x0b\x32\x19.gossip.MembershipRequestH\x00\x12-\n\x07mem_res\x18\x07 \x01(\x0b\x32\x1a.gossip.MembershipResponseH\x00\x12\'\n\x08\x64\x61ta_msg\x18\x08 \x01(\x0b\x32\x13.gossip.DataMessageH\x00\x12$\n\x05hello\x18\t \x01(\x0b\x32\x13.gossip.GossipHelloH\x00\x12&\n\x08\x64\x61ta_dig\x18\n \x01(\x0b\x32\x12.gossip.DataDigestH\x00\x12\'\n\x08\x64\x61ta_req\x18\x0b \x01(\x0b\x32\x13.gossip.DataRequestH\x00\x12)\n\x0b\x64\x61ta_update\x18\x0c \x01(\x0b\x32\x12.gossip.DataUpdateH\x00\x12\x1e\n\x05\x65mpty\x18\r \x01(\x0b\x32\r.gossip.EmptyH\x00\x12%\n\x04\x63onn\x18\x0e \x01(\x0b\x32\x15.gossip.ConnEstablishH\x00\x12\'\n\nstate_info\x18\x0f \x01(\x0b\x32\x11.gossip.StateInfoH\x00\x12\x33\n\x0estate_snapshot\x18\x10 \x01(\x0b\x32\x19.gossip.StateInfoSnapshotH\x00\x12;\n\x13state_info_pull_req\x18\x11 \x01(\x0b\x32\x1c.gossip.StateInfoPullRequestH\x00\x12\x33\n\rstate_request\x18\x12 \x01(\x0b\x32\x1a.gossip.RemoteStateRequestH\x00\x12\x35\n\x0estate_response\x18\x13 \x01(\x0b\x32\x1b.gossip.RemoteStateResponseH\x00\x12\x33\n\x0eleadership_msg\x18\x14 \x01(\x0b\x32\x19.gossip.LeadershipMessageH\x00\x12-\n\rpeer_identity\x18\x15 \x01(\x0b\x32\x14.gossip.PeerIdentityH\x00\x12&\n\x03\x61\x63k\x18\x16 \x01(\x0b\x32\x17.gossip.AcknowledgementH\x00\x12\x32\n\nprivateReq\x18\x17 \x01(\x0b\x32\x1c.gossip.RemotePvtDataRequestH\x00\x12\x33\n\nprivateRes\x18\x18 \x01(\x0b\x32\x1d.gossip.RemotePvtDataResponseH\x00\x12\x32\n\x0cprivate_data\x18\x19 \x01(\x0b\x32\x1a.gossip.PrivateDataMessageH\x00\"_\n\x03Tag\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x0c\n\x08ORG_ONLY\x10\x02\x12\r\n\tCHAN_ONLY\x10\x03\x12\x10\n\x0c\x43HAN_AND_ORG\x10\x04\x12\x0f\n\x0b\x43HAN_OR_ORG\x10\x05\x42\t\n\x07\x63ontent\"}\n\tStateInfo\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x0e\n\x06pki_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63hannel_MAC\x18\x04 \x01(\x0c\x12&\n\nproperties\x18\x05 \x01(\x0b\x32\x12.gossip.Properties\"`\n\nProperties\x12\x15\n\rledger_height\x18\x01 \x01(\x04\x12\x14\n\x0cleft_channel\x18\x02 \x01(\x08\x12%\n\nchaincodes\x18\x03 \x03(\x0b\x32\x11.gossip.Chaincode\"7\n\x11StateInfoSnapshot\x12\"\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x10.gossip.Envelope\"+\n\x14StateInfoPullRequest\x12\x13\n\x0b\x63hannel_MAC\x18\x01 \x01(\x0c\"H\n\rConnEstablish\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12\x10\n\x08identity\x18\x02 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x03 \x01(\x0c\">\n\x0cPeerIdentity\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12\x0c\n\x04\x63\x65rt\x18\x02 \x01(\x0c\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"T\n\x0b\x44\x61taRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x64igests\x18\x02 \x03(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"U\n\x0bGossipHello\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"b\n\nDataUpdate\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x1e\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x10.gossip.Envelope\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"S\n\nDataDigest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x64igests\x18\x02 \x03(\x0c\x12%\n\x08msg_type\x18\x03 \x01(\x0e\x32\x13.gossip.PullMsgType\"/\n\x0b\x44\x61taMessage\x12 \n\x07payload\x18\x01 \x01(\x0b\x32\x0f.gossip.Payload\"=\n\x12PrivateDataMessage\x12\'\n\x07payload\x18\x01 \x01(\x0b\x32\x16.gossip.PrivatePayload\">\n\x07Payload\x12\x0f\n\x07seq_num\x18\x01 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x14\n\x0cprivate_data\x18\x03 \x03(\x0c\"\xbb\x01\n\x0ePrivatePayload\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\r\n\x05tx_id\x18\x03 \x01(\t\x12\x15\n\rprivate_rwset\x18\x04 \x01(\x0c\x12\x1a\n\x12private_sim_height\x18\x05 \x01(\x04\x12;\n\x12\x63ollection_configs\x18\x06 \x01(\x0b\x32\x1f.common.CollectionConfigPackage\"i\n\x0c\x41liveMessage\x12\"\n\nmembership\x18\x01 \x01(\x0b\x32\x0e.gossip.Member\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x10\n\x08identity\x18\x04 \x01(\x0c\"`\n\x11LeadershipMessage\x12\x0e\n\x06pki_id\x18\x01 \x01(\x0c\x12#\n\ttimestamp\x18\x02 \x01(\x0b\x32\x10.gossip.PeerTime\x12\x16\n\x0eis_declaration\x18\x03 \x01(\x08\",\n\x08PeerTime\x12\x0f\n\x07inc_num\x18\x01 \x01(\x04\x12\x0f\n\x07seq_num\x18\x02 \x01(\x04\"N\n\x11MembershipRequest\x12*\n\x10self_information\x18\x01 \x01(\x0b\x32\x10.gossip.Envelope\x12\r\n\x05known\x18\x02 \x03(\x0c\"U\n\x12MembershipResponse\x12\x1f\n\x05\x61live\x18\x01 \x03(\x0b\x32\x10.gossip.Envelope\x12\x1e\n\x04\x64\x65\x61\x64\x18\x02 \x03(\x0b\x32\x10.gossip.Envelope\"<\n\x06Member\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12\x0e\n\x06pki_id\x18\x03 \x01(\x0c\"\x07\n\x05\x45mpty\"@\n\x12RemoteStateRequest\x12\x15\n\rstart_seq_num\x18\x01 \x01(\x04\x12\x13\n\x0b\x65nd_seq_num\x18\x02 \x01(\x04\"8\n\x13RemoteStateResponse\x12!\n\x08payloads\x18\x01 \x03(\x0b\x32\x0f.gossip.Payload\">\n\x14RemotePvtDataRequest\x12&\n\x07\x64igests\x18\x01 \x03(\x0b\x32\x15.gossip.PvtDataDigest\"n\n\rPvtDataDigest\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x11\n\tblock_seq\x18\x04 \x01(\x04\x12\x14\n\x0cseq_in_block\x18\x05 \x01(\x04\"A\n\x15RemotePvtDataResponse\x12(\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x16.gossip.PvtDataElement\"H\n\x0ePvtDataElement\x12%\n\x06\x64igest\x18\x01 \x01(\x0b\x32\x15.gossip.PvtDataDigest\x12\x0f\n\x07payload\x18\x02 \x03(\x0c\":\n\x0ePvtDataPayload\x12\x17\n\x0ftx_seq_in_block\x18\x01 \x01(\x04\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\" \n\x0f\x41\x63knowledgement\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"<\n\tChaincode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c*=\n\x0bPullMsgType\x12\r\n\tUNDEFINED\x10\x00\x12\r\n\tBLOCK_MSG\x10\x01\x12\x10\n\x0cIDENTITY_MSG\x10\x02\x32j\n\x06Gossip\x12\x38\n\x0cGossipStream\x12\x10.gossip.Envelope\x1a\x10.gossip.Envelope\"\x00(\x01\x30\x01\x12&\n\x04Ping\x12\r.gossip.Empty\x1a\r.gossip.Empty\"\x00\x42-Z+github.com/hyperledger/fabric/protos/gossipb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_common_dot_collection__pb2.DESCRIPTOR,])

_PULLMSGTYPE = _descriptor.EnumDescriptor(
  name='PullMsgType',
  full_name='gossip.PullMsgType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_MSG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTITY_MSG', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3722,
  serialized_end=3783,
)
_sym_db.RegisterEnumDescriptor(_PULLMSGTYPE)

PullMsgType = enum_type_wrapper.EnumTypeWrapper(_PULLMSGTYPE)
UNDEFINED = 0
BLOCK_MSG = 1
IDENTITY_MSG = 2


_GOSSIPMESSAGE_TAG = _descriptor.EnumDescriptor(
  name='Tag',
  full_name='gossip.GossipMessage.Tag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORG_ONLY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAN_ONLY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAN_AND_ORG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAN_OR_ORG', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1339,
  serialized_end=1434,
)
_sym_db.RegisterEnumDescriptor(_GOSSIPMESSAGE_TAG)


_ENVELOPE = _descriptor.Descriptor(
  name='Envelope',
  full_name='gossip.Envelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.Envelope.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='gossip.Envelope.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_envelope', full_name='gossip.Envelope.secret_envelope', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=174,
)


_SECRETENVELOPE = _descriptor.Descriptor(
  name='SecretEnvelope',
  full_name='gossip.SecretEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.SecretEnvelope.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='gossip.SecretEnvelope.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=228,
)


_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='gossip.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internalEndpoint', full_name='gossip.Secret.internalEndpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='gossip.Secret.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=230,
  serialized_end=277,
)


_GOSSIPMESSAGE = _descriptor.Descriptor(
  name='GossipMessage',
  full_name='gossip.GossipMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='gossip.GossipMessage.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel', full_name='gossip.GossipMessage.channel', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='gossip.GossipMessage.tag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alive_msg', full_name='gossip.GossipMessage.alive_msg', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_req', full_name='gossip.GossipMessage.mem_req', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_res', full_name='gossip.GossipMessage.mem_res', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_msg', full_name='gossip.GossipMessage.data_msg', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hello', full_name='gossip.GossipMessage.hello', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_dig', full_name='gossip.GossipMessage.data_dig', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_req', full_name='gossip.GossipMessage.data_req', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_update', full_name='gossip.GossipMessage.data_update', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='gossip.GossipMessage.empty', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn', full_name='gossip.GossipMessage.conn', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_info', full_name='gossip.GossipMessage.state_info', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_snapshot', full_name='gossip.GossipMessage.state_snapshot', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_info_pull_req', full_name='gossip.GossipMessage.state_info_pull_req', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_request', full_name='gossip.GossipMessage.state_request', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_response', full_name='gossip.GossipMessage.state_response', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leadership_msg', full_name='gossip.GossipMessage.leadership_msg', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_identity', full_name='gossip.GossipMessage.peer_identity', index=19,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ack', full_name='gossip.GossipMessage.ack', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='privateReq', full_name='gossip.GossipMessage.privateReq', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='privateRes', full_name='gossip.GossipMessage.privateRes', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_data', full_name='gossip.GossipMessage.private_data', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GOSSIPMESSAGE_TAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='gossip.GossipMessage.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=280,
  serialized_end=1445,
)


_STATEINFO = _descriptor.Descriptor(
  name='StateInfo',
  full_name='gossip.StateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gossip.StateInfo.timestamp', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pki_id', full_name='gossip.StateInfo.pki_id', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_MAC', full_name='gossip.StateInfo.channel_MAC', index=2,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='gossip.StateInfo.properties', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1572,
)


_PROPERTIES = _descriptor.Descriptor(
  name='Properties',
  full_name='gossip.Properties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_height', full_name='gossip.Properties.ledger_height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_channel', full_name='gossip.Properties.left_channel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chaincodes', full_name='gossip.Properties.chaincodes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1574,
  serialized_end=1670,
)


_STATEINFOSNAPSHOT = _descriptor.Descriptor(
  name='StateInfoSnapshot',
  full_name='gossip.StateInfoSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='gossip.StateInfoSnapshot.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1727,
)


_STATEINFOPULLREQUEST = _descriptor.Descriptor(
  name='StateInfoPullRequest',
  full_name='gossip.StateInfoPullRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_MAC', full_name='gossip.StateInfoPullRequest.channel_MAC', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1772,
)


_CONNESTABLISH = _descriptor.Descriptor(
  name='ConnEstablish',
  full_name='gossip.ConnEstablish',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pki_id', full_name='gossip.ConnEstablish.pki_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identity', full_name='gossip.ConnEstablish.identity', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cert_hash', full_name='gossip.ConnEstablish.tls_cert_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1774,
  serialized_end=1846,
)


_PEERIDENTITY = _descriptor.Descriptor(
  name='PeerIdentity',
  full_name='gossip.PeerIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pki_id', full_name='gossip.PeerIdentity.pki_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cert', full_name='gossip.PeerIdentity.cert', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='gossip.PeerIdentity.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1910,
)


_DATAREQUEST = _descriptor.Descriptor(
  name='DataRequest',
  full_name='gossip.DataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='gossip.DataRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digests', full_name='gossip.DataRequest.digests', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='gossip.DataRequest.msg_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=1996,
)


_GOSSIPHELLO = _descriptor.Descriptor(
  name='GossipHello',
  full_name='gossip.GossipHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='gossip.GossipHello.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='gossip.GossipHello.metadata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='gossip.GossipHello.msg_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1998,
  serialized_end=2083,
)


_DATAUPDATE = _descriptor.Descriptor(
  name='DataUpdate',
  full_name='gossip.DataUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='gossip.DataUpdate.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='gossip.DataUpdate.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='gossip.DataUpdate.msg_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2085,
  serialized_end=2183,
)


_DATADIGEST = _descriptor.Descriptor(
  name='DataDigest',
  full_name='gossip.DataDigest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='gossip.DataDigest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digests', full_name='gossip.DataDigest.digests', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='gossip.DataDigest.msg_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2185,
  serialized_end=2268,
)


_DATAMESSAGE = _descriptor.Descriptor(
  name='DataMessage',
  full_name='gossip.DataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.DataMessage.payload', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2270,
  serialized_end=2317,
)


_PRIVATEDATAMESSAGE = _descriptor.Descriptor(
  name='PrivateDataMessage',
  full_name='gossip.PrivateDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.PrivateDataMessage.payload', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2319,
  serialized_end=2380,
)


_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='gossip.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='gossip.Payload.seq_num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='gossip.Payload.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_data', full_name='gossip.Payload.private_data', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2382,
  serialized_end=2444,
)


_PRIVATEPAYLOAD = _descriptor.Descriptor(
  name='PrivatePayload',
  full_name='gossip.PrivatePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='gossip.PrivatePayload.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='gossip.PrivatePayload.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='gossip.PrivatePayload.tx_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_rwset', full_name='gossip.PrivatePayload.private_rwset', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_sim_height', full_name='gossip.PrivatePayload.private_sim_height', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_configs', full_name='gossip.PrivatePayload.collection_configs', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2447,
  serialized_end=2634,
)


_ALIVEMESSAGE = _descriptor.Descriptor(
  name='AliveMessage',
  full_name='gossip.AliveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='membership', full_name='gossip.AliveMessage.membership', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gossip.AliveMessage.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identity', full_name='gossip.AliveMessage.identity', index=2,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2636,
  serialized_end=2741,
)


_LEADERSHIPMESSAGE = _descriptor.Descriptor(
  name='LeadershipMessage',
  full_name='gossip.LeadershipMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pki_id', full_name='gossip.LeadershipMessage.pki_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gossip.LeadershipMessage.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_declaration', full_name='gossip.LeadershipMessage.is_declaration', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2743,
  serialized_end=2839,
)


_PEERTIME = _descriptor.Descriptor(
  name='PeerTime',
  full_name='gossip.PeerTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inc_num', full_name='gossip.PeerTime.inc_num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='gossip.PeerTime.seq_num', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2841,
  serialized_end=2885,
)


_MEMBERSHIPREQUEST = _descriptor.Descriptor(
  name='MembershipRequest',
  full_name='gossip.MembershipRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='self_information', full_name='gossip.MembershipRequest.self_information', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='known', full_name='gossip.MembershipRequest.known', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2887,
  serialized_end=2965,
)


_MEMBERSHIPRESPONSE = _descriptor.Descriptor(
  name='MembershipResponse',
  full_name='gossip.MembershipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alive', full_name='gossip.MembershipResponse.alive', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dead', full_name='gossip.MembershipResponse.dead', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2967,
  serialized_end=3052,
)


_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='gossip.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='gossip.Member.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='gossip.Member.metadata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pki_id', full_name='gossip.Member.pki_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3054,
  serialized_end=3114,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='gossip.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3116,
  serialized_end=3123,
)


_REMOTESTATEREQUEST = _descriptor.Descriptor(
  name='RemoteStateRequest',
  full_name='gossip.RemoteStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_seq_num', full_name='gossip.RemoteStateRequest.start_seq_num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_seq_num', full_name='gossip.RemoteStateRequest.end_seq_num', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3125,
  serialized_end=3189,
)


_REMOTESTATERESPONSE = _descriptor.Descriptor(
  name='RemoteStateResponse',
  full_name='gossip.RemoteStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payloads', full_name='gossip.RemoteStateResponse.payloads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3191,
  serialized_end=3247,
)


_REMOTEPVTDATAREQUEST = _descriptor.Descriptor(
  name='RemotePvtDataRequest',
  full_name='gossip.RemotePvtDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='digests', full_name='gossip.RemotePvtDataRequest.digests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3249,
  serialized_end=3311,
)


_PVTDATADIGEST = _descriptor.Descriptor(
  name='PvtDataDigest',
  full_name='gossip.PvtDataDigest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='gossip.PvtDataDigest.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='gossip.PvtDataDigest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection', full_name='gossip.PvtDataDigest.collection', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_seq', full_name='gossip.PvtDataDigest.block_seq', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_in_block', full_name='gossip.PvtDataDigest.seq_in_block', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3313,
  serialized_end=3423,
)


_REMOTEPVTDATARESPONSE = _descriptor.Descriptor(
  name='RemotePvtDataResponse',
  full_name='gossip.RemotePvtDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='gossip.RemotePvtDataResponse.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3425,
  serialized_end=3490,
)


_PVTDATAELEMENT = _descriptor.Descriptor(
  name='PvtDataElement',
  full_name='gossip.PvtDataElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='digest', full_name='gossip.PvtDataElement.digest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.PvtDataElement.payload', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3492,
  serialized_end=3564,
)


_PVTDATAPAYLOAD = _descriptor.Descriptor(
  name='PvtDataPayload',
  full_name='gossip.PvtDataPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_seq_in_block', full_name='gossip.PvtDataPayload.tx_seq_in_block', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='gossip.PvtDataPayload.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3566,
  serialized_end=3624,
)


_ACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='Acknowledgement',
  full_name='gossip.Acknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='gossip.Acknowledgement.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3626,
  serialized_end=3658,
)


_CHAINCODE = _descriptor.Descriptor(
  name='Chaincode',
  full_name='gossip.Chaincode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gossip.Chaincode.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='gossip.Chaincode.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='gossip.Chaincode.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3660,
  serialized_end=3720,
)

_ENVELOPE.fields_by_name['secret_envelope'].message_type = _SECRETENVELOPE
_SECRET.oneofs_by_name['content'].fields.append(
  _SECRET.fields_by_name['internalEndpoint'])
_SECRET.fields_by_name['internalEndpoint'].containing_oneof = _SECRET.oneofs_by_name['content']
_GOSSIPMESSAGE.fields_by_name['tag'].enum_type = _GOSSIPMESSAGE_TAG
_GOSSIPMESSAGE.fields_by_name['alive_msg'].message_type = _ALIVEMESSAGE
_GOSSIPMESSAGE.fields_by_name['mem_req'].message_type = _MEMBERSHIPREQUEST
_GOSSIPMESSAGE.fields_by_name['mem_res'].message_type = _MEMBERSHIPRESPONSE
_GOSSIPMESSAGE.fields_by_name['data_msg'].message_type = _DATAMESSAGE
_GOSSIPMESSAGE.fields_by_name['hello'].message_type = _GOSSIPHELLO
_GOSSIPMESSAGE.fields_by_name['data_dig'].message_type = _DATADIGEST
_GOSSIPMESSAGE.fields_by_name['data_req'].message_type = _DATAREQUEST
_GOSSIPMESSAGE.fields_by_name['data_update'].message_type = _DATAUPDATE
_GOSSIPMESSAGE.fields_by_name['empty'].message_type = _EMPTY
_GOSSIPMESSAGE.fields_by_name['conn'].message_type = _CONNESTABLISH
_GOSSIPMESSAGE.fields_by_name['state_info'].message_type = _STATEINFO
_GOSSIPMESSAGE.fields_by_name['state_snapshot'].message_type = _STATEINFOSNAPSHOT
_GOSSIPMESSAGE.fields_by_name['state_info_pull_req'].message_type = _STATEINFOPULLREQUEST
_GOSSIPMESSAGE.fields_by_name['state_request'].message_type = _REMOTESTATEREQUEST
_GOSSIPMESSAGE.fields_by_name['state_response'].message_type = _REMOTESTATERESPONSE
_GOSSIPMESSAGE.fields_by_name['leadership_msg'].message_type = _LEADERSHIPMESSAGE
_GOSSIPMESSAGE.fields_by_name['peer_identity'].message_type = _PEERIDENTITY
_GOSSIPMESSAGE.fields_by_name['ack'].message_type = _ACKNOWLEDGEMENT
_GOSSIPMESSAGE.fields_by_name['privateReq'].message_type = _REMOTEPVTDATAREQUEST
_GOSSIPMESSAGE.fields_by_name['privateRes'].message_type = _REMOTEPVTDATARESPONSE
_GOSSIPMESSAGE.fields_by_name['private_data'].message_type = _PRIVATEDATAMESSAGE
_GOSSIPMESSAGE_TAG.containing_type = _GOSSIPMESSAGE
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['alive_msg'])
_GOSSIPMESSAGE.fields_by_name['alive_msg'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['mem_req'])
_GOSSIPMESSAGE.fields_by_name['mem_req'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['mem_res'])
_GOSSIPMESSAGE.fields_by_name['mem_res'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['data_msg'])
_GOSSIPMESSAGE.fields_by_name['data_msg'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['hello'])
_GOSSIPMESSAGE.fields_by_name['hello'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['data_dig'])
_GOSSIPMESSAGE.fields_by_name['data_dig'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['data_req'])
_GOSSIPMESSAGE.fields_by_name['data_req'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['data_update'])
_GOSSIPMESSAGE.fields_by_name['data_update'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['empty'])
_GOSSIPMESSAGE.fields_by_name['empty'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['conn'])
_GOSSIPMESSAGE.fields_by_name['conn'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['state_info'])
_GOSSIPMESSAGE.fields_by_name['state_info'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['state_snapshot'])
_GOSSIPMESSAGE.fields_by_name['state_snapshot'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['state_info_pull_req'])
_GOSSIPMESSAGE.fields_by_name['state_info_pull_req'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['state_request'])
_GOSSIPMESSAGE.fields_by_name['state_request'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['state_response'])
_GOSSIPMESSAGE.fields_by_name['state_response'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['leadership_msg'])
_GOSSIPMESSAGE.fields_by_name['leadership_msg'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['peer_identity'])
_GOSSIPMESSAGE.fields_by_name['peer_identity'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['ack'])
_GOSSIPMESSAGE.fields_by_name['ack'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['privateReq'])
_GOSSIPMESSAGE.fields_by_name['privateReq'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['privateRes'])
_GOSSIPMESSAGE.fields_by_name['privateRes'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_GOSSIPMESSAGE.oneofs_by_name['content'].fields.append(
  _GOSSIPMESSAGE.fields_by_name['private_data'])
_GOSSIPMESSAGE.fields_by_name['private_data'].containing_oneof = _GOSSIPMESSAGE.oneofs_by_name['content']
_STATEINFO.fields_by_name['timestamp'].message_type = _PEERTIME
_STATEINFO.fields_by_name['properties'].message_type = _PROPERTIES
_PROPERTIES.fields_by_name['chaincodes'].message_type = _CHAINCODE
_STATEINFOSNAPSHOT.fields_by_name['elements'].message_type = _ENVELOPE
_DATAREQUEST.fields_by_name['msg_type'].enum_type = _PULLMSGTYPE
_GOSSIPHELLO.fields_by_name['msg_type'].enum_type = _PULLMSGTYPE
_DATAUPDATE.fields_by_name['data'].message_type = _ENVELOPE
_DATAUPDATE.fields_by_name['msg_type'].enum_type = _PULLMSGTYPE
_DATADIGEST.fields_by_name['msg_type'].enum_type = _PULLMSGTYPE
_DATAMESSAGE.fields_by_name['payload'].message_type = _PAYLOAD
_PRIVATEDATAMESSAGE.fields_by_name['payload'].message_type = _PRIVATEPAYLOAD
_PRIVATEPAYLOAD.fields_by_name['collection_configs'].message_type = hfc_dot_protos_dot_common_dot_collection__pb2._COLLECTIONCONFIGPACKAGE
_ALIVEMESSAGE.fields_by_name['membership'].message_type = _MEMBER
_ALIVEMESSAGE.fields_by_name['timestamp'].message_type = _PEERTIME
_LEADERSHIPMESSAGE.fields_by_name['timestamp'].message_type = _PEERTIME
_MEMBERSHIPREQUEST.fields_by_name['self_information'].message_type = _ENVELOPE
_MEMBERSHIPRESPONSE.fields_by_name['alive'].message_type = _ENVELOPE
_MEMBERSHIPRESPONSE.fields_by_name['dead'].message_type = _ENVELOPE
_REMOTESTATERESPONSE.fields_by_name['payloads'].message_type = _PAYLOAD
_REMOTEPVTDATAREQUEST.fields_by_name['digests'].message_type = _PVTDATADIGEST
_REMOTEPVTDATARESPONSE.fields_by_name['elements'].message_type = _PVTDATAELEMENT
_PVTDATAELEMENT.fields_by_name['digest'].message_type = _PVTDATADIGEST
DESCRIPTOR.message_types_by_name['Envelope'] = _ENVELOPE
DESCRIPTOR.message_types_by_name['SecretEnvelope'] = _SECRETENVELOPE
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['GossipMessage'] = _GOSSIPMESSAGE
DESCRIPTOR.message_types_by_name['StateInfo'] = _STATEINFO
DESCRIPTOR.message_types_by_name['Properties'] = _PROPERTIES
DESCRIPTOR.message_types_by_name['StateInfoSnapshot'] = _STATEINFOSNAPSHOT
DESCRIPTOR.message_types_by_name['StateInfoPullRequest'] = _STATEINFOPULLREQUEST
DESCRIPTOR.message_types_by_name['ConnEstablish'] = _CONNESTABLISH
DESCRIPTOR.message_types_by_name['PeerIdentity'] = _PEERIDENTITY
DESCRIPTOR.message_types_by_name['DataRequest'] = _DATAREQUEST
DESCRIPTOR.message_types_by_name['GossipHello'] = _GOSSIPHELLO
DESCRIPTOR.message_types_by_name['DataUpdate'] = _DATAUPDATE
DESCRIPTOR.message_types_by_name['DataDigest'] = _DATADIGEST
DESCRIPTOR.message_types_by_name['DataMessage'] = _DATAMESSAGE
DESCRIPTOR.message_types_by_name['PrivateDataMessage'] = _PRIVATEDATAMESSAGE
DESCRIPTOR.message_types_by_name['Payload'] = _PAYLOAD
DESCRIPTOR.message_types_by_name['PrivatePayload'] = _PRIVATEPAYLOAD
DESCRIPTOR.message_types_by_name['AliveMessage'] = _ALIVEMESSAGE
DESCRIPTOR.message_types_by_name['LeadershipMessage'] = _LEADERSHIPMESSAGE
DESCRIPTOR.message_types_by_name['PeerTime'] = _PEERTIME
DESCRIPTOR.message_types_by_name['MembershipRequest'] = _MEMBERSHIPREQUEST
DESCRIPTOR.message_types_by_name['MembershipResponse'] = _MEMBERSHIPRESPONSE
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['RemoteStateRequest'] = _REMOTESTATEREQUEST
DESCRIPTOR.message_types_by_name['RemoteStateResponse'] = _REMOTESTATERESPONSE
DESCRIPTOR.message_types_by_name['RemotePvtDataRequest'] = _REMOTEPVTDATAREQUEST
DESCRIPTOR.message_types_by_name['PvtDataDigest'] = _PVTDATADIGEST
DESCRIPTOR.message_types_by_name['RemotePvtDataResponse'] = _REMOTEPVTDATARESPONSE
DESCRIPTOR.message_types_by_name['PvtDataElement'] = _PVTDATAELEMENT
DESCRIPTOR.message_types_by_name['PvtDataPayload'] = _PVTDATAPAYLOAD
DESCRIPTOR.message_types_by_name['Acknowledgement'] = _ACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['Chaincode'] = _CHAINCODE
DESCRIPTOR.enum_types_by_name['PullMsgType'] = _PULLMSGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Envelope = _reflection.GeneratedProtocolMessageType('Envelope', (_message.Message,), dict(
  DESCRIPTOR = _ENVELOPE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Envelope)
  ))
_sym_db.RegisterMessage(Envelope)

SecretEnvelope = _reflection.GeneratedProtocolMessageType('SecretEnvelope', (_message.Message,), dict(
  DESCRIPTOR = _SECRETENVELOPE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.SecretEnvelope)
  ))
_sym_db.RegisterMessage(SecretEnvelope)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), dict(
  DESCRIPTOR = _SECRET,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Secret)
  ))
_sym_db.RegisterMessage(Secret)

GossipMessage = _reflection.GeneratedProtocolMessageType('GossipMessage', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPMESSAGE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.GossipMessage)
  ))
_sym_db.RegisterMessage(GossipMessage)

StateInfo = _reflection.GeneratedProtocolMessageType('StateInfo', (_message.Message,), dict(
  DESCRIPTOR = _STATEINFO,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.StateInfo)
  ))
_sym_db.RegisterMessage(StateInfo)

Properties = _reflection.GeneratedProtocolMessageType('Properties', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTIES,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Properties)
  ))
_sym_db.RegisterMessage(Properties)

StateInfoSnapshot = _reflection.GeneratedProtocolMessageType('StateInfoSnapshot', (_message.Message,), dict(
  DESCRIPTOR = _STATEINFOSNAPSHOT,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.StateInfoSnapshot)
  ))
_sym_db.RegisterMessage(StateInfoSnapshot)

StateInfoPullRequest = _reflection.GeneratedProtocolMessageType('StateInfoPullRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATEINFOPULLREQUEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.StateInfoPullRequest)
  ))
_sym_db.RegisterMessage(StateInfoPullRequest)

ConnEstablish = _reflection.GeneratedProtocolMessageType('ConnEstablish', (_message.Message,), dict(
  DESCRIPTOR = _CONNESTABLISH,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.ConnEstablish)
  ))
_sym_db.RegisterMessage(ConnEstablish)

PeerIdentity = _reflection.GeneratedProtocolMessageType('PeerIdentity', (_message.Message,), dict(
  DESCRIPTOR = _PEERIDENTITY,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PeerIdentity)
  ))
_sym_db.RegisterMessage(PeerIdentity)

DataRequest = _reflection.GeneratedProtocolMessageType('DataRequest', (_message.Message,), dict(
  DESCRIPTOR = _DATAREQUEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.DataRequest)
  ))
_sym_db.RegisterMessage(DataRequest)

GossipHello = _reflection.GeneratedProtocolMessageType('GossipHello', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPHELLO,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.GossipHello)
  ))
_sym_db.RegisterMessage(GossipHello)

DataUpdate = _reflection.GeneratedProtocolMessageType('DataUpdate', (_message.Message,), dict(
  DESCRIPTOR = _DATAUPDATE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.DataUpdate)
  ))
_sym_db.RegisterMessage(DataUpdate)

DataDigest = _reflection.GeneratedProtocolMessageType('DataDigest', (_message.Message,), dict(
  DESCRIPTOR = _DATADIGEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.DataDigest)
  ))
_sym_db.RegisterMessage(DataDigest)

DataMessage = _reflection.GeneratedProtocolMessageType('DataMessage', (_message.Message,), dict(
  DESCRIPTOR = _DATAMESSAGE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.DataMessage)
  ))
_sym_db.RegisterMessage(DataMessage)

PrivateDataMessage = _reflection.GeneratedProtocolMessageType('PrivateDataMessage', (_message.Message,), dict(
  DESCRIPTOR = _PRIVATEDATAMESSAGE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PrivateDataMessage)
  ))
_sym_db.RegisterMessage(PrivateDataMessage)

Payload = _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), dict(
  DESCRIPTOR = _PAYLOAD,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Payload)
  ))
_sym_db.RegisterMessage(Payload)

PrivatePayload = _reflection.GeneratedProtocolMessageType('PrivatePayload', (_message.Message,), dict(
  DESCRIPTOR = _PRIVATEPAYLOAD,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PrivatePayload)
  ))
_sym_db.RegisterMessage(PrivatePayload)

AliveMessage = _reflection.GeneratedProtocolMessageType('AliveMessage', (_message.Message,), dict(
  DESCRIPTOR = _ALIVEMESSAGE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.AliveMessage)
  ))
_sym_db.RegisterMessage(AliveMessage)

LeadershipMessage = _reflection.GeneratedProtocolMessageType('LeadershipMessage', (_message.Message,), dict(
  DESCRIPTOR = _LEADERSHIPMESSAGE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.LeadershipMessage)
  ))
_sym_db.RegisterMessage(LeadershipMessage)

PeerTime = _reflection.GeneratedProtocolMessageType('PeerTime', (_message.Message,), dict(
  DESCRIPTOR = _PEERTIME,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PeerTime)
  ))
_sym_db.RegisterMessage(PeerTime)

MembershipRequest = _reflection.GeneratedProtocolMessageType('MembershipRequest', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERSHIPREQUEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.MembershipRequest)
  ))
_sym_db.RegisterMessage(MembershipRequest)

MembershipResponse = _reflection.GeneratedProtocolMessageType('MembershipResponse', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERSHIPRESPONSE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.MembershipResponse)
  ))
_sym_db.RegisterMessage(MembershipResponse)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Member)
  ))
_sym_db.RegisterMessage(Member)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), dict(
  DESCRIPTOR = _EMPTY,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Empty)
  ))
_sym_db.RegisterMessage(Empty)

RemoteStateRequest = _reflection.GeneratedProtocolMessageType('RemoteStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOTESTATEREQUEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.RemoteStateRequest)
  ))
_sym_db.RegisterMessage(RemoteStateRequest)

RemoteStateResponse = _reflection.GeneratedProtocolMessageType('RemoteStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOTESTATERESPONSE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.RemoteStateResponse)
  ))
_sym_db.RegisterMessage(RemoteStateResponse)

RemotePvtDataRequest = _reflection.GeneratedProtocolMessageType('RemotePvtDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEPVTDATAREQUEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.RemotePvtDataRequest)
  ))
_sym_db.RegisterMessage(RemotePvtDataRequest)

PvtDataDigest = _reflection.GeneratedProtocolMessageType('PvtDataDigest', (_message.Message,), dict(
  DESCRIPTOR = _PVTDATADIGEST,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PvtDataDigest)
  ))
_sym_db.RegisterMessage(PvtDataDigest)

RemotePvtDataResponse = _reflection.GeneratedProtocolMessageType('RemotePvtDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEPVTDATARESPONSE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.RemotePvtDataResponse)
  ))
_sym_db.RegisterMessage(RemotePvtDataResponse)

PvtDataElement = _reflection.GeneratedProtocolMessageType('PvtDataElement', (_message.Message,), dict(
  DESCRIPTOR = _PVTDATAELEMENT,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PvtDataElement)
  ))
_sym_db.RegisterMessage(PvtDataElement)

PvtDataPayload = _reflection.GeneratedProtocolMessageType('PvtDataPayload', (_message.Message,), dict(
  DESCRIPTOR = _PVTDATAPAYLOAD,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.PvtDataPayload)
  ))
_sym_db.RegisterMessage(PvtDataPayload)

Acknowledgement = _reflection.GeneratedProtocolMessageType('Acknowledgement', (_message.Message,), dict(
  DESCRIPTOR = _ACKNOWLEDGEMENT,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Acknowledgement)
  ))
_sym_db.RegisterMessage(Acknowledgement)

Chaincode = _reflection.GeneratedProtocolMessageType('Chaincode', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODE,
  __module__ = 'hfc.protos.gossip.message_pb2'
  # @@protoc_insertion_point(class_scope:gossip.Chaincode)
  ))
_sym_db.RegisterMessage(Chaincode)


DESCRIPTOR._options = None

_GOSSIP = _descriptor.ServiceDescriptor(
  name='Gossip',
  full_name='gossip.Gossip',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3785,
  serialized_end=3891,
  methods=[
  _descriptor.MethodDescriptor(
    name='GossipStream',
    full_name='gossip.Gossip.GossipStream',
    index=0,
    containing_service=None,
    input_type=_ENVELOPE,
    output_type=_ENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='gossip.Gossip.Ping',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GOSSIP)

DESCRIPTOR.services_by_name['Gossip'] = _GOSSIP

# @@protoc_insertion_point(module_scope)
